@@ -3,55 +3,27 @@
 /**
  * addressbook.php
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Functions and classes for the addressbook system.
  *
- * $Id: addressbook.php,v 1.38 2002/01/31 13:06:11 simond Exp $
+ * @version $Id: addressbook.php,v 1.47.2.10 2004/12/27 15:03:42 kink Exp $
+ * @package squirrelmail
+ * @subpackage addressbook
  */
 
-/*
-   This is the path to the global site-wide addressbook.
-   It looks and feels just like a user's .abook file
-   If this is in the data directory, use "$data_dir/global.abook"
-   If not, specify the path as though it was accessed from the
-   src/ directory ("../global.abook" -> in main directory)
+global $addrbook_dsn, $addrbook_global_dsn;
 
-   If you don't want a global site-wide addressbook, comment these
-   two lines out.  (They are disabled by default.)
-
-   The global addressbook is unmodifiable by anyone.  You must actually
-   use a shell script or whatnot to modify the contents.
-
-  global $data_dir;
-  $address_book_global_filename = "$data_dir/global.abook";
-
-  Include backends here.
-*/
-
-require_once('../functions/abook_local_file.php');
-require_once('../functions/abook_ldap_server.php');
-
-global $addrbook_dsn;
-
-/* Use this if you wanna have a global address book */
-if (isset($address_book_global_filename)) {
-    include_once('../functions/abook_global_file.php');
-}
-
-/* Only load database backend if database is configured */
-if(isset($addrbook_dsn) && !empty($addrbook_dsn)) {
-  include_once('../functions/abook_database.php');
-}
-
-/*
+/**
    Create and initialize an addressbook object.
    Returns the created object
 */
 function addressbook_init($showerr = true, $onlylocal = false) {
     global $data_dir, $username, $ldap_server, $address_book_global_filename;
     global $addrbook_dsn, $addrbook_table;
+    global $abook_global_file, $abook_global_file_writeable;
+    global $addrbook_global_dsn, $addrbook_global_table, $addrbook_global_writeable, $addrbook_global_listing;
 
     /* Create a new addressbook object */
     $abook = new AddressBook;
@@ -86,14 +58,43 @@ function addressbook_init($showerr = true, $onlylocal = false) {
     }
 
     /* This would be for the global addressbook */
-    if (isset($address_book_global_filename)) {
-        $r = $abook->add_backend('global_file');
+    if (isset($abook_global_file) && isset($abook_global_file_writeable)
+        && trim($abook_global_file)!=''){
+        // Detect place of address book
+        if (! preg_match("/[\/\\\]/",$abook_global_file)) {
+            // no path chars
+            $abook_global_filename=$data_dir . $abook_global_file;
+        } elseif (preg_match("/^\/|\w:/",$abook_global_file)) {
+            // full path is set in options (starts with slash or x:)
+            $abook_global_filename=$abook_global_file;
+        } else {
+            $abook_global_filename=SM_PATH . $abook_global_file;
+        }
+        $r = $abook->add_backend('local_file',array('filename'=>$abook_global_filename,
+                                                    'name' => _("Global address book"),
+                                                    'detect_writeable' => false,
+                                                    'writeable'=> $abook_global_file_writeable));
         if (!$r && $showerr) {
             echo _("Error initializing global addressbook.");
             exit;
         }
     }
 
+    /* Load global addressbook from SQL if configured */
+    if (isset($addrbook_global_dsn) && !empty($addrbook_global_dsn)) {
+        /* Database configured */
+        if (!isset($addrbook_global_table) || empty($addrbook_global_table)) {
+            $addrbook_global_table = 'global_abook';
+        }
+        $r = $abook->add_backend('database',
+                                 Array('dsn' => $addrbook_global_dsn,
+                                       'owner' => 'global',
+                                       'name' => _("Global address book"),
+                                       'writeable' => $addrbook_global_writeable,
+                                       'listing' => $addrbook_global_listing,
+                                       'table' => $addrbook_global_table));
+    }
+
     if ($onlylocal) {
         return $abook;
     }
@@ -106,7 +107,7 @@ function addressbook_init($showerr = true, $onlylocal = false) {
                 $r = $abook->add_backend('ldap_server', $param);
                 if (!$r && $showerr) {
                     printf( '&nbsp;' . _("Error initializing LDAP server %s:") .
-                            "<BR>\n", $param['host']);
+                            "<br />\n", $param['host']);
                     echo '&nbsp;' . $abook->error;
                     exit;
                 }
@@ -122,7 +123,7 @@ function addressbook_init($showerr = true, $onlylocal = false) {
 /*
  *   Had to move this function outside of the Addressbook Class
  *   PHP 4.0.4 Seemed to be having problems with inline functions.
- */    
+ */
 function addressbook_cmp($a,$b) {
 
     if($a['backend'] > $b['backend']) {
@@ -130,16 +131,16 @@ function addressbook_cmp($a,$b) {
     } else if($a['backend'] < $b['backend']) {
         return -1;
     }
-    
+
     return (strtolower($a['name']) > strtolower($b['name'])) ? 1 : -1;
 
 }
 
 
-/*
+/**
  * This is the main address book class that connect all the
  * backends and provide services to the functions above.
- *
+ * @package squirrelmail
  */
 
 class AddressBook {
@@ -149,10 +150,10 @@ class AddressBook {
     var $error       = '';
     var $localbackend = 0;
     var $localbackendname = '';
-    
+
       // Constructor function.
     function AddressBook() {
-        $localbackendname = _("Personal address book");
+        $this->localbackendname = _("Personal address book");
     }
 
     /*
@@ -190,7 +191,7 @@ class AddressBook {
 
         $newback->bnum = $this->numbackends;
         $this->backends[$this->numbackends] = $newback;
-        
+
         /* Store ID of first local backend added */
         if ($this->localbackend == 0 && $newback->btype == 'local') {
             $this->localbackend = $this->numbackends;
@@ -201,6 +202,24 @@ class AddressBook {
     }
 
 
+    /*
+     * This function takes a $row array as returned by the addressbook
+     * search and returns an e-mail address with the full name or
+     * nickname optionally prepended.
+     */
+
+    function full_address($row) {
+        global $addrsrch_fullname, $data_dir, $username;
+        $prefix = getPref($data_dir, $username, 'addrsrch_fullname');
+        if (($prefix != "" || (isset($addrsrch_fullname) &&
+            $prefix == $addrsrch_fullname)) && $prefix != 'noprefix') {
+            $name = ($prefix == 'nickname' ? $row['nickname'] : $row['name']);
+            return $name . ' <' . trim($row['email']) . '>';
+        } else {
+            return trim($row['email']);
+        }
+    }
+
     /*
         Return a list of addresses matching expression in
         all backends of a given type.
@@ -220,7 +239,7 @@ class AddressBook {
                 if (is_array($res)) {
                     $ret = array_merge($ret, $res);
                 } else {
-                    $this->error .= "<br>\n" . $backend->error;
+                    $this->error .= "<br />\n" . $backend->error;
                     $failed++;
                 }
             }
@@ -236,7 +255,7 @@ class AddressBook {
 
             $ret = $this->backends[$bnum]->search($expression);
             if (!is_array($ret)) {
-                $this->error .= "<br>\n" . $this->backends[$bnum]->error;
+                $this->error .= "<br />\n" . $this->backends[$bnum]->error;
                 $ret = FALSE;
             }
         }
@@ -247,11 +266,11 @@ class AddressBook {
 
     /* Return a sorted search */
     function s_search($expression, $bnum = -1) {
-    
+
         $ret = $this->search($expression, $bnum);
         if ( is_array( $ret ) ) {
             usort($ret, 'addressbook_cmp');
-        }    
+        }
         return $ret;
     }
 
@@ -261,9 +280,9 @@ class AddressBook {
      *  local backends.
      */
     function lookup($alias, $bnum = -1) {
-    
+
         $ret = array();
-    
+
         if ($bnum > -1) {
             $res = $this->backends[$bnum]->lookup($alias);
             if (is_array($res)) {
@@ -273,7 +292,7 @@ class AddressBook {
                return false;
             }
         }
-    
+
         $sel = $this->get_backend_list('local');
         for ($i = 0 ; $i < sizeof($sel) ; $i++) {
             $backend = &$sel[$i];
@@ -287,7 +306,7 @@ class AddressBook {
                return false;
             }
         }
-        
+
         return $ret;
     }
 
@@ -295,13 +314,13 @@ class AddressBook {
     /* Return all addresses */
     function list_addr($bnum = -1) {
         $ret = array();
-        
+
         if ($bnum == -1) {
-            $sel = $this->get_backend_list('local');
+            $sel = $this->get_backend_list('');
         } else {
             $sel = array(0 => &$this->backends[$bnum]);
         }
-        
+
         for ($i = 0 ; $i < sizeof($sel) ; $i++) {
             $backend = &$sel[$i];
             $backend->error = '';
@@ -313,7 +332,7 @@ class AddressBook {
                return false;
             }
         }
-        
+
         return $ret;
     }
 
@@ -323,7 +342,7 @@ class AddressBook {
      * to, or false if it failed.
      */
     function add($userdata, $bnum) {
-    
+
         /* Validate data */
         if (!is_array($userdata)) {
             $this->error = _("Invalid input data");
@@ -340,18 +359,18 @@ class AddressBook {
         if (empty($userdata['nickname'])) {
             $userdata['nickname'] = $userdata['email'];
         }
-        
+
         if (eregi('[ \\:\\|\\#\\"\\!]', $userdata['nickname'])) {
             $this->error = _("Nickname contains illegal characters");
             return false;
         }
-        
+
         /* Check that specified backend accept new entries */
         if (!$this->backends[$bnum]->writeable) {
             $this->error = _("Addressbook is read-only");
             return false;
         }
-        
+
         /* Add address to backend */
         $res = $this->backends[$bnum]->add($userdata);
         if ($res) {
@@ -360,7 +379,7 @@ class AddressBook {
             $this->error = $this->backends[$bnum]->error;
             return false;
         }
-        
+
         return false;  // Not reached
     } /* end of add() */
 
@@ -370,23 +389,23 @@ class AddressBook {
      * If $alias is an array, all users in the array are removed.
      */
     function remove($alias, $bnum) {
-    
+
         /* Check input */
         if (empty($alias)) {
             return true;
         }
-        
+
         /* Convert string to single element array */
         if (!is_array($alias)) {
             $alias = array(0 => $alias);
         }
-        
+
         /* Check that specified backend is writable */
         if (!$this->backends[$bnum]->writeable) {
             $this->error = _("Addressbook is read-only");
             return false;
         }
-        
+
         /* Remove user from backend */
         $res = $this->backends[$bnum]->remove($alias);
         if ($res) {
@@ -395,7 +414,7 @@ class AddressBook {
             $this->error = $this->backends[$bnum]->error;
             return false;
         }
-        
+
         return FALSE;  /* Not reached */
     } /* end of remove() */
 
@@ -405,12 +424,12 @@ class AddressBook {
      * If $alias is an array, all users in the array are removed.
      */
     function modify($alias, $userdata, $bnum) {
-    
+
         /* Check input */
         if (empty($alias) || !is_string($alias)) {
             return true;
         }
-        
+
         /* Validate data */
         if(!is_array($userdata)) {
             $this->error = _("Invalid input data");
@@ -424,22 +443,22 @@ class AddressBook {
             $this->error = _("E-mail address is missing");
             return false;
         }
-        
+
         if (eregi('[\\: \\|\\#"\\!]', $userdata['nickname'])) {
             $this->error = _("Nickname contains illegal characters");
             return false;
         }
-        
+
         if (empty($userdata['nickname'])) {
             $userdata['nickname'] = $userdata['email'];
         }
-        
+
         /* Check that specified backend is writable */
         if (!$this->backends[$bnum]->writeable) {
             $this->error = _("Addressbook is read-only");;
             return false;
         }
-        
+
         /* Modify user in backend */
         $res = $this->backends[$bnum]->modify($alias, $userdata);
         if ($res) {
@@ -448,15 +467,16 @@ class AddressBook {
             $this->error = $this->backends[$bnum]->error;
             return false;
         }
-        
+
         return FALSE;  /* Not reached */
     } /* end of modify() */
-    
-    
+
+
 } /* End of class Addressbook */
 
-/*
+/**
  * Generic backend that all other backends extend
+ * @package squirrelmail
  */
 class addressbook_backend {
 
@@ -464,7 +484,7 @@ class addressbook_backend {
     var $btype      = 'dummy';
     var $bname      = 'dummy';
     var $sname      = 'Dummy backend';
-    
+
     /*
      * Variables common for all backends, but that
      * should not be changed by the backends.
@@ -472,40 +492,40 @@ class addressbook_backend {
     var $bnum       = -1;
     var $error      = '';
     var $writeable  = false;
-    
+
     function set_error($string) {
         $this->error = '[' . $this->sname . '] ' . $string;
         return false;
     }
-    
-    
+
+
     /* ========================== Public ======================== */
-    
+
     function search($expression) {
         $this->set_error('search not implemented');
         return false;
     }
-    
+
     function lookup($alias) {
         $this->set_error('lookup not implemented');
         return false;
     }
-    
+
     function list_addr() {
         $this->set_error('list_addr not implemented');
         return false;
     }
-    
+
     function add($userdata) {
         $this->set_error('add not implemented');
         return false;
     }
-    
+
     function remove($alias) {
         $this->set_error('delete not implemented');
         return false;
     }
-    
+
     function modify($alias, $newuserdata) {
         $this->set_error('modify not implemented');
         return false;
@@ -513,7 +533,9 @@ class addressbook_backend {
 
 }
 
-/* Sort array by the key "name" */
+/**
+ * Sort array by the key "name"
+ */
 function alistcmp($a,$b) {
     if ($a['backend'] > $b['backend']) {
         return 1;
@@ -525,4 +547,19 @@ function alistcmp($a,$b) {
     return (strtolower($a['name']) > strtolower($b['name'])) ? 1 : -1;
 }
 
-?>
+
+/*
+  PHP 5 requires that the class be made first, which seems rather
+  logical, and should have been the way it was generated the first time.
+*/
+
+require_once(SM_PATH . 'functions/abook_local_file.php');
+require_once(SM_PATH . 'functions/abook_ldap_server.php');
+
+/* Only load database backend if database is configured */
+if((isset($addrbook_dsn) && !empty($addrbook_dsn)) ||
+ (isset($addrbook_global_dsn) && !empty($addrbook_global_dsn))) {
+  include_once(SM_PATH . 'functions/abook_database.php');
+}
+
+?>
\ No newline at end of file
