@@ -3,14 +3,20 @@
 /**
  * attachment_common.php
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This file provides the handling of often-used attachment types.
  *
- * $Id: attachment_common.php,v 1.11 2002/03/08 21:18:17 stekkel Exp $
+ * @version $Id: attachment_common.php,v 1.25.2.6 2004/12/27 15:03:43 kink Exp $
+ * @package squirrelmail
  */
 
+/**
+ * FIXME Needs phpDocumentator style documentation
+ */
+require_once(SM_PATH . 'functions/global.php');
+
 global $attachment_common_show_images_list;
 $attachment_common_show_images_list = array();
 
@@ -25,9 +31,11 @@ $FileExtensionToMimeType = array('bmp'  => 'image/x-bitmap',
                                  'png'  => 'image/png',
                                  'rtf'  => 'text/richtext',
                                  'txt'  => 'text/plain',
+                                 'patch'=> 'text/plain',
                                  'vcf'  => 'text/x-vcard');
 
 /* Register browser-supported image types */
+sqgetGlobalVar('attachment_common_types', $attachment_common_types);
 if (isset($attachment_common_types)) {
     /* Don't run this before being logged in. That may happen
        when plugins include mime.php */
@@ -49,7 +57,6 @@ if (isset($attachment_common_types)) {
 }
 
 /* Register text-type attachments */
-//register_attachment_common('message/rfc822', 'link_text');
 register_attachment_common('message/rfc822', 'link_message');
 register_attachment_common('text/plain',     'link_text');
 register_attachment_common('text/richtext',  'link_text');
@@ -60,6 +67,7 @@ register_attachment_common('text/html',      'link_html');
 
 /* Register vcards */
 register_attachment_common('text/x-vcard',   'link_vcard');
+register_attachment_common('text/directory', 'link_vcard');
 
 /* Register rules for general types.
  * These will be used if there isn't a more specific rule available. */
@@ -79,135 +87,119 @@ function register_attachment_common($type, $func) {
 }
 
 
-function attachment_common_link_text(&$Args)
-{
-    /* If there is a text attachment, we would like to create a 'view' button
+function attachment_common_link_text(&$Args) {
+    /* If there is a text attachment, we would like to create a "View" button
        that links to the text attachment viewer.
-      
+
        $Args[1] = the array of actions
-      
-       Use our plugin name for adding an action
-       $Args[1]['attachment_common'] = array for href and text
-      
+
+       Use the name of this file for adding an action
+       $Args[1]['attachment_common'] = Array for href and text
+
        $Args[1]['attachment_common']['text'] = What is displayed
-       $Args[1]['attachment_common']['href'] = Where it links to
-      
-       This sets the 'href' of this plugin for a new link. */
-    $Args[1]['attachment_common']['href'] = '../src/download.php?startMessage=' .
-        $Args[2] . '&amp;passed_id=' . $Args[3] . '&amp;mailbox=' . $Args[4] .
-        '&amp;passed_ent_id=' . $Args[5] . '&amp;override_type0=text&amp;override_type1=plain';
-    
-    /* If we got here from a search, we should preserve these variables */
-    if ($Args[8] && $Args[9])
-        $Args[1]['attachment_common']['href'] .= '&amp;where=' . 
-        urlencode($Args[8]) . '&amp;what=' . urlencode($Args[9]);
-  
-    /* The link that we created needs a name.  "view" will be displayed for
-       all text attachments handled by this plugin. */
-    $Args[1]['attachment_common']['text'] = _("view");
+       $Args[1]['attachment_common']['href'] = Where it links to */
+    sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
+
+    $Args[1]['attachment_common']['href'] = SM_PATH . 'src/view_text.php?'. $QUERY_STRING;
+    $Args[1]['attachment_common']['href'] =
+          set_url_var($Args[1]['attachment_common']['href'],
+          'ent_id',$Args[5]);
+
+    /* The link that we created needs a name. */
+    $Args[1]['attachment_common']['text'] = _("View");
 
     /* Each attachment has a filename on the left, which is a link.
        Where that link points to can be changed.  Just in case the link above
        for viewing text attachments is not the same as the default link for
        this file, we'll change it.
-      
+
        This is a lot better in the image links, since the defaultLink will just
        download the image, but the one that we set it to will format the page
        to have an image tag in the center (looking a lot like this text viewer) */
     $Args[6] = $Args[1]['attachment_common']['href'];
 }
 
-
-function attachment_common_link_message(&$Args)
-{
-    $Args[1]['attachment_common']['href'] = '../src/download.php?startMessage=' .
+function attachment_common_link_message(&$Args) {
+    $Args[1]['attachment_common']['href'] = SM_PATH . 'src/read_body.php?startMessage=' .
         $Args[2] . '&amp;passed_id=' . $Args[3] . '&amp;mailbox=' . $Args[4] .
         '&amp;passed_ent_id=' . $Args[5] . '&amp;override_type0=message&amp;override_type1=rfc822';
-    /* The link that we created needs a name.  "view" will be displayed for
-       all text attachments handled by this plugin. */
-    $Args[1]['attachment_common']['text'] = _("view");
-}
 
-
-function attachment_common_link_html(&$Args)
-{
-    $Args[1]['attachment_common']['href'] = '../src/download.php?startMessage=' . 
-        $Args[2] . '&amp;passed_id=' . $Args[3] . '&amp;mailbox=' . $Args[4] .
-       '&amp;passed_ent_id=' . $Args[5] . '&amp;override_type0=text&amp;override_type1=html';
-    
-    if ($Args[8] && $Args[9]) {
-        $Args[1]['attachment_common']['href'] .= '&amp;where=' . 
-        urlencode($Args[8]) . '&amp;what=' . urlencode($Args[9]);
-    }
-
-    $Args[1]['attachment_common']['text'] = _("view");
+    $Args[1]['attachment_common']['text'] = _("View");
 
     $Args[6] = $Args[1]['attachment_common']['href'];
 }
 
 
-function attachment_common_link_image(&$Args)
-{
+function attachment_common_link_html(&$Args) {
+    sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
+
+    $Args[1]['attachment_common']['href'] = SM_PATH . 'src/view_text.php?'. $QUERY_STRING.
+       /* why use the overridetype? can this be removed */
+       '&amp;override_type0=text&amp;override_type1=html';
+    $Args[1]['attachment_common']['href'] =
+          set_url_var($Args[1]['attachment_common']['href'],
+          'ent_id',$Args[5]);
+
+    $Args[1]['attachment_common']['text'] = _("View");
+
+    $Args[6] = $Args[1]['attachment_common']['href'];
+}
+
+function attachment_common_link_image(&$Args) {
     global $attachment_common_show_images, $attachment_common_show_images_list;
-    
+
+    sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
+
     $info['passed_id'] = $Args[3];
     $info['mailbox'] = $Args[4];
     $info['ent_id'] = $Args[5];
-    
+
     $attachment_common_show_images_list[] = $info;
-    
-    $Args[1]['attachment_common']['href'] = '../src/image.php?startMessage=' .
-        $Args[2] . '&amp;passed_id=' . $Args[3] . '&amp;mailbox=' . $Args[4] .
-        '&amp;passed_ent_id=' . $Args[5];
-    
-    if ($Args[8] && $Args[9]) {
-        $Args[1]['attachment_common']['href'] .= '&amp;where=' . 
-        urlencode($Args[8]) . '&amp;what=' . urlencode($Args[9]);
-    }
-  
-    $Args[1]['attachment_common']['text'] = _("view");
-    
-    $Args[6] = $Args[1]['attachment_common']['href'];
-    
-}
 
+    $Args[1]['attachment_common']['href'] = SM_PATH . 'src/image.php?'. $QUERY_STRING;
+    $Args[1]['attachment_common']['href'] =
+          set_url_var($Args[1]['attachment_common']['href'],
+          'ent_id',$Args[5]);
+
+    $Args[1]['attachment_common']['text'] = _("View");
 
-function attachment_common_link_vcard(&$Args)
-{
-    $Args[1]['attachment_common']['href'] = '../src/vcard.php?startMessage=' .
-        $Args[2] . '&amp;passed_id=' . $Args[3] . '&amp;mailbox=' . $Args[4] .
-        '&amp;passed_ent_id=' . $Args[5];
-  
-    if (isset($where) && isset($what))
-        $Args[1]['attachment_common']['href'] .= '&amp;where=' . 
-        urlencode($Args[8]) . '&amp;what=' . urlencode($Args[9]);
-  
-    $Args[1]['attachment_common']['text'] = _("Business Card");
-  
     $Args[6] = $Args[1]['attachment_common']['href'];
 }
 
 
-function attachment_common_octet_stream(&$Args)
-{
+function attachment_common_link_vcard(&$Args) {
+    sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
+
+    $Args[1]['attachment_common']['href'] = SM_PATH . 'src/vcard.php?'. $QUERY_STRING;
+    $Args[1]['attachment_common']['href'] =
+          set_url_var($Args[1]['attachment_common']['href'],
+          'ent_id',$Args[5]);
+
+    $Args[1]['attachment_common']['text'] = _("View Business Card");
+
+    $Args[6] = $Args[1]['attachment_common']['href'];
+}
+
+
+function attachment_common_octet_stream(&$Args) {
     global $FileExtensionToMimeType;
-   
+
     do_hook('attachment_common-load_mime_types');
-   
+
     ereg('\\.([^\\.]+)$', $Args[7], $Regs);
-  
+
     $Ext = strtolower($Regs[1]);
-   
+
     if ($Ext == '' || ! isset($FileExtensionToMimeType[$Ext]))
-        return;       
-   
-    $Ret = do_hook('attachment ' . $FileExtensionToMimeType[$Ext], 
-        $Args[1], $Args[2], $Args[3], $Args[4], $Args[5], $Args[6], 
+        return;
+
+    $Ret = do_hook('attachment ' . $FileExtensionToMimeType[$Ext],
+        $Args[1], $Args[2], $Args[3], $Args[4], $Args[5], $Args[6],
         $Args[7], $Args[8], $Args[9]);
-       
+
     foreach ($Ret as $a => $b) {
         $Args[$a] = $b;
     }
 }
 
-?>
+?>
\ No newline at end of file
