@@ -3,23 +3,27 @@
 /**
  * tree.php
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This code provides various string manipulation functions that are
  * used by the rest of the Squirrelmail code.
  *
- * $Id: tree.php,v 1.21 2002/01/23 18:12:36 philippe_mingo Exp $
+ * @version $Id: tree.php,v 1.25.2.6 2004/12/27 15:03:46 kink Exp $
+ * @package squirrelmail
  */
 
-require_once('../functions/imap.php');
+/** Clearly, this needs the IMAP functions.. */
+require_once(SM_PATH . 'functions/imap.php');
 
 /**
- * findParentForChild
+ * Recursive function to find the correct parent for a new node.
  *
- * Recursive function to find the correct parent for a new node
+ * @param mixed value the value to find a parent for
+ * @param int treeIndexToStart where to start the search, usually the root node (0)
+ * @param array tree the tree to search
+ * @return int the index of the parent
  */
-
 function findParentForChild($value, $treeIndexToStart, $tree) {
     // is $value in $tree[$treeIndexToStart]['value']
     if ((isset($tree[$treeIndexToStart])) && (strstr($value, $tree[$treeIndexToStart]['value']))) {
@@ -41,6 +45,13 @@ function findParentForChild($value, $treeIndexToStart, $tree) {
     }
 }
 
+/**
+ * Will insert a new value into the tree, based on a given comparison value.
+ *
+ * @param mixed comparisonValue the value to determine where the new element should be placed.
+ * @param mixed value the new node to insert
+ * @param array tree the tree to insert the node in, by ref
+ */
 function addChildNodeToTree($comparisonValue, $value, &$tree) {
     $parentNode = findParentForChild($comparisonValue, 0, $tree);
 
@@ -60,6 +71,14 @@ function addChildNodeToTree($comparisonValue, $value, &$tree) {
     }
 }
 
+/**
+ * Recursively walk the tree of trash mailboxes and delete all folders and messages
+ *
+ * @param int index the place in the tree to start, usually 0
+ * @param stream imap_stream the IMAP connection to send commands to
+ * @param array tree the tree to walk
+ * @return void
+ */
 function walkTreeInPreOrderEmptyTrash($index, $imap_stream, $tree) {
     global $trash_folder;
     if ($tree[$index]['doIHaveChildren']) {
@@ -69,27 +88,36 @@ function walkTreeInPreOrderEmptyTrash($index, $imap_stream, $tree) {
         if ($tree[$index]['value'] != $trash_folder) {
             sqimap_mailbox_delete($imap_stream, $tree[$index]['value']);
         } else {
-            $numMessages = sqimap_get_num_messages($imap_stream, $trash_folder);
-            if ($numMessages > 0) {
-            sqimap_mailbox_select($imap_stream, $trash_folder);
-            sqimap_messages_flag ($imap_stream, 1, $numMessages, 'Deleted');
-            sqimap_mailbox_expunge($imap_stream, $trash_folder, true);
+            $mbx_response = sqimap_mailbox_select($imap_stream, $trash_folder);
+            if ($mbx_response['EXISTS'] > 0) {
+               sqimap_messages_flag ($imap_stream, 1, '*', 'Deleted', true);
+               // CLOSE === EXPUNGE and UNSELECT
+               sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
             }
         }
     } else {
         if ($tree[$index]['value'] != $trash_folder) {
             sqimap_mailbox_delete($imap_stream, $tree[$index]['value']);
         } else {
-            $numMessages = sqimap_get_num_messages($imap_stream, $trash_folder);
-            if ($numMessages > 0) {
-            sqimap_mailbox_select($imap_stream, $trash_folder);
-            sqimap_messages_flag ($imap_stream, 1, $numMessages, 'Deleted');
-            sqimap_mailbox_expunge($imap_stream, $trash_folder, true);
+            $mbx_response = sqimap_mailbox_select($imap_stream, $trash_folder);
+            if ($mbx_response['EXISTS'] > 0) {
+                sqimap_messages_flag ($imap_stream, 1, '*', 'Deleted', true);
+                // CLOSE === EXPUNGE and UNSELECT
+                sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
             }
         }
     }
 }
 
+
+/**
+ * Recursively delete a tree of mail folders.
+ *
+ * @param int index the place in the tree to start, usually 0
+ * @param stream imap_stream the IMAP connection to send commands to
+ * @param array tree the tree to walk
+ * @return void
+ */
 function walkTreeInPreOrderDeleteFolders($index, $imap_stream, $tree) {
     if ($tree[$index]['doIHaveChildren']) {
         for ($j = 0; $j < count($tree[$index]['subNodes']); $j++) {
@@ -101,40 +129,55 @@ function walkTreeInPreOrderDeleteFolders($index, $imap_stream, $tree) {
     }
 }
 
+/**
+ * Recursively walk a tree of folders to create them under the trash folder.
+ */
 function walkTreeInPostOrderCreatingFoldersUnderTrash($index, $imap_stream, $tree, $topFolderName) {
     global $trash_folder, $delimiter;
 
-    $position = strrpos($topFolderName, $delimiter) + 1;
+    $position = strrpos($topFolderName, $delimiter);
+    if ($position !== FALSE) {
+        $position++;
+    }
     $subFolderName = substr($tree[$index]['value'], $position);
 
     if ($tree[$index]['doIHaveChildren']) {
         sqimap_mailbox_create($imap_stream, $trash_folder . $delimiter . $subFolderName, "");
-        sqimap_mailbox_select($imap_stream, $tree[$index]['value']);
-
-        $messageCount = sqimap_get_num_messages($imap_stream, $tree[$index]['value']);
-        if ($messageCount > 0)
-            sqimap_messages_copy($imap_stream, 1, $messageCount, $trash_folder . $delimiter . $subFolderName);
-
+        $mbx_response = sqimap_mailbox_select($imap_stream, $tree[$index]['value']);
+        $messageCount = $mbx_response['EXISTS'];
+        if ($messageCount > 0) {
+            sqimap_messages_copy($imap_stream, 1, '*', $trash_folder . $delimiter . $subFolderName);
+        }
+        // after copy close the mailbox to get in unselected state
+        sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
         for ($j = 0;$j < count($tree[$index]['subNodes']); $j++)
             walkTreeInPostOrderCreatingFoldersUnderTrash($tree[$index]['subNodes'][$j], $imap_stream, $tree, $topFolderName);
     } else {
         sqimap_mailbox_create($imap_stream, $trash_folder . $delimiter . $subFolderName, '');
-        sqimap_mailbox_select($imap_stream, $tree[$index]['value']);
-
-        $messageCount = sqimap_get_num_messages($imap_stream, $tree[$index]['value']);
-        if ($messageCount > 0)
-            sqimap_messages_copy($imap_stream, 1, $messageCount, $trash_folder . $delimiter . $subFolderName);
+        $mbx_response = sqimap_mailbox_select($imap_stream, $tree[$index]['value']);
+        $messageCount = $mbx_response['EXISTS'];
+        if ($messageCount > 0) {
+            sqimap_messages_copy($imap_stream, 1, '*', $trash_folder . $delimiter . $subFolderName);
+        }
+        // after copy close the mailbox to get in unselected state
+        sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
     }
 }
 
+/**
+ * Recursive function that outputs a tree In-Pre-Order.
+ * @param int index the node to start (usually 0)
+ * @param array tree the tree to walk
+ * @return void
+ */
 function simpleWalkTreePre($index, $tree) {
     if ($tree[$index]['doIHaveChildren']) {
         for ($j = 0; $j < count($tree[$index]['subNodes']); $j++) {
             simpleWalkTreePre($tree[$index]['subNodes'][$j], $tree);
         }
-        echo $tree[$index]['value'] . '<br>';
+        echo $tree[$index]['value'] . '<br />';
     } else {
-        echo $tree[$index]['value'] . '<br>';
+        echo $tree[$index]['value'] . '<br />';
     }
 }
-?>
+?>
\ No newline at end of file
