@@ -3,15 +3,19 @@
 /**
  * url_parser.php
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This code provides various string manipulation functions that are
  * used by the rest of the Squirrelmail code.
  *
- * $Id: url_parser.php,v 1.39 2002/03/02 20:28:33 simond Exp $
+ * @version $Id: url_parser.php,v 1.44.2.6 2004/12/27 15:03:46 kink Exp $
+ * @package squirrelmail
  */
 
+/**
+ * Undocumented - complain, then patch.
+ */
 function replaceBlock (&$in, $replace, $start, $end) {
     $begin = substr($in,0,$start);
     $end   = substr($in,$end,strlen($in)-$end);
@@ -36,39 +40,22 @@ $Email_RegExp_Match = '[0-9a-z]([-_.+]?[0-9a-z])*(%' . $Host_RegExp_Match .
 
 function parseEmail (&$body) {
     global $color, $Email_RegExp_Match, $compose_new_win;
-    $Size = strlen($body);
+    $sbody     = $body;
+    $addresses = array();
 
-    /*
-     * This is here in case we ever decide to use highlighting of searched
-     * text.  this does it for email addresses
-     *
-     * if ($what && ($where == "BODY" || $where == "TEXT")) {
-     *    eregi ($Email_RegExp_Match, $body, $regs);
-     *    $oldaddr = $regs[0];
-     *    if ($oldaddr) {
-     *       $newaddr = eregi_replace ($what, "<b><font color=\"$color[2]\">$what</font></font></b>", $oldaddr);
-     *       $body = str_replace ($oldaddr, "<a href=\"../src/compose.php?send_to=$oldaddr\">$newaddr</a>", $body);
-     *    }
-     * } else {
-     *    $body = eregi_replace ($Email_RegExp_Match, "<a href=\"../src/compose.php?send_to=\\0\">\\0</a>", $body);
-     * }
-     */
-
-    if( eregi($Email_RegExp_Match, $body, $regs) ) {
-        if ($compose_new_win == '1') {
-            $body = str_replace($regs[0],  '<a href="../src/compose.php?send_to='.urlencode($regs[0]).'" target="compose_window" onClick="comp_in_new()">'.$regs[0].'</a>', $body);
-        }
-        else {
-            $body = str_replace($regs[0],  '<a href="../src/compose.php?send_to='.
-            urlencode($regs[0]).'">'.$regs[0].'</a>', $body);
-        }
+    /* Find all the email addresses in the body */
+    while(eregi($Email_RegExp_Match, $sbody, $regs)) {
+        $addresses[$regs[0]] = $regs[0];
+        $start = strpos($sbody, $regs[0]) + strlen($regs[0]);
+        $sbody = substr($sbody, $start);
     }
-
-    /* If there are any changes, it'll just get bigger. */
-    if ($Size != strlen($body)) {
-        return 1;
+    /* Replace each email address with a compose URL */
+    foreach ($addresses as $email) {
+        $comp_uri = makeComposeLink('src/compose.php?send_to='.urlencode($email), $email);
+        $body = str_replace($email, $comp_uri, $body);
     }
-    return 0;
+    /* Return number of unique addresses found */
+    return count($addresses);
 }
 
 
@@ -85,50 +72,52 @@ $url_parser_url_tokens = array(
     'news://');
 
 global $url_parser_poss_ends;
-$url_parser_poss_ends = array(' ', "\n", "\r", '<', '>', ".\r", ".\n", 
-    '.&nbsp;', '&nbsp;', ')', '(', '&quot;', '&lt;', '&gt;', '.<', 
+$url_parser_poss_ends = array(' ', "\n", "\r", '<', '>', ".\r", ".\n",
+    '.&nbsp;', '&nbsp;', ')', '(', '&quot;', '&lt;', '&gt;', '.<',
     ']', '[', '{', '}', "\240", ', ', '. ', ",\n", ",\r");
 
 
 function parseUrl (&$body) {
-    global $url_parser_poss_ends, $url_parser_url_tokens;;
-    $start = 0;
-    $target_pos = strlen($body);
-      
-    while ($start != $target_pos) {
+    global $url_parser_poss_ends, $url_parser_url_tokens;
+    $start      = 0;
+    $blength    = strlen($body);
+
+    while ($start != $blength) {
         $target_token = '';
-        
+        $target_pos = $blength;
+
         /* Find the first token to replace */
         foreach ($url_parser_url_tokens as $the_token) {
             $pos = strpos(strtolower($body), $the_token, $start);
             if (is_int($pos) && $pos < $target_pos) {
-                $target_pos = $pos;
+                $target_pos   = $pos;
                 $target_token = $the_token;
             }
         }
-        
+
         /* Look for email addresses between $start and $target_pos */
-        $check_str = substr($body, $start, $target_pos);
-       
+        $check_str = substr($body, $start, $target_pos-$start);
+
         if (parseEmail($check_str)) {
             replaceBlock($body, $check_str, $start, $target_pos);
+            $blength    = strlen($body);
             $target_pos = strlen($check_str) + $start;
         }
 
         /* If there was a token to replace, replace it */
         if ($target_token != '') {
             /* Find the end of the URL */
-            $end=strlen($body); 
-            foreach ($url_parser_poss_ends as $key => $val) {
-                $enda = strpos($body,$val,$target_pos);
+            $end = $blength;
+            foreach ($url_parser_poss_ends as $val) {
+                $enda = strpos($body, $val, $target_pos);
                 if (is_int($enda) && $enda < $end) {
                     $end = $enda;
                 }
             }
-         
+
             /* Extract URL */
             $url = substr($body, $target_pos, $end-$target_pos);
-          
+
             /* Needed since lines are not passed with \n or \r */
             while ( ereg("[,\.]$", $url) ) {
                 $url = substr( $url, 0, -1 );
@@ -140,16 +129,16 @@ function parseUrl (&$body) {
                 $url_str = "<a href=\"$url\" target=\"_blank\">$url</a>";
                 replaceBlock($body,$url_str,$target_pos,$end);
                 $target_pos += strlen($url_str);
-            } 
-            else { 
-                 // Not quite a valid link, skip ahead to next chance
-                 $target_pos += strlen($target_token);
+            }
+            else {
+                // Not quite a valid link, skip ahead to next chance
+                $target_pos += strlen($target_token);
             }
         }
-        
+
         /* Move forward */
-        $start = $target_pos;
-        $target_pos = strlen($body);
+        $start   = $target_pos;
+        $blength = strlen($body);
     }
-} 
-?>
+}
+?>
\ No newline at end of file
