@@ -3,15 +3,15 @@
 /**
  * index.php -- Displays the main frameset
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Redirects to the login page.
  *
- * $Id: index.php,v 1.13 2002/02/19 15:05:03 philippe_mingo Exp $
+ * $Id: index.php,v 1.14.2.3 2004/12/27 15:03:41 kink Exp $
  */
 
-header("Location: src/login.php\n\n");
-exit();
+header('Location: src/login.php');
 
-?>
\ No newline at end of file
+?>
+<html></html>
