@@ -1,17 +1,17 @@
-<?PHP
-
+<?php
 /**
- * defines.php
+ * Administrator plugin - Option definitions
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
- * Philippe Mingo
- *
- * $Id: defines.php,v 1.22 2002/03/16 12:46:09 simond Exp $
+ * @version $Id: defines.php,v 1.32.2.9 2004/12/28 10:37:09 tokul Exp $
+ * @author Philippe Mingo
+ * @copyright (c) 1999-2005 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @package plugins
+ * @subpackage administrator
  */
 
-require_once( '../functions/constants.php' );
+/** */
+require_once( SM_PATH . 'functions/constants.php' );
 
 /* Define constants for the various option types. */
 define('SMOPT_TYPE_UNDEFINED', -1);
@@ -29,6 +29,7 @@ define('SMOPT_TYPE_THEME', 10);
 define('SMOPT_TYPE_PLUGINS', 11);
 define('SMOPT_TYPE_LDAP', 12);
 define('SMOPT_TYPE_EXTERNAL', 32);
+define('SMOPT_TYPE_PATH',33);
 
 global $languages;
 
@@ -48,7 +49,7 @@ for ($lsv = 100; $lsv <= 300; $lsv += 10) {
 $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                              'type' => SMOPT_TYPE_COMMENT,
                                              'size' => 7 ),
-                 'SM_ver' => array( 'name' => _("Squirrelmail Version"),
+                 'SM_ver' => array( 'name' => _("SquirrelMail Version"),
                                     'type' => SMOPT_TYPE_EXTERNAL,
                                     'value' => "$version" ),
                  'PHP_ver' => array( 'name' => _("PHP Version"),
@@ -61,26 +62,27 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                        'type' => SMOPT_TYPE_STRING,
                                        'size' => 40 ),
                  '$org_logo' => array( 'name' => _("Organization Logo"),
-                                       'type' => SMOPT_TYPE_STRING,
-                                       'size' => 40 ),
+                                       'type' => SMOPT_TYPE_PATH,
+                                       'size' => 40,
+                                       'default' => '../images/sm_logo.png'),
                  '$org_logo_width' => array( 'name'    => _("Organization Logo Width"),
-                                             'type'    => SMOPT_TYPE_INTEGER,
+                                             'type'    => SMOPT_TYPE_STRING,
                                              'size'    => 5,
                                              'default' => 0),
                  '$org_logo_height' => array( 'name'    => _("Organization Logo Height"),
-                                              'type'    => SMOPT_TYPE_INTEGER,
+                                              'type'    => SMOPT_TYPE_STRING,
                                               'size'    => 5,
                                               'default' => 0),
                  '$org_title' => array( 'name' => _("Organization Title"),
                                         'type' => SMOPT_TYPE_STRING,
                                         'size' => 40 ),
                  '$signout_page' => array( 'name' => _("Signout Page"),
-                                           'type' => SMOPT_TYPE_STRING,
+                                           'type' => SMOPT_TYPE_PATH,
                                            'size' => 40 ),
-                 '$squirrelmail_default_language' => array( 'name' => _("Default Language"),
-                                                            'type' => SMOPT_TYPE_STRLIST,
-                                                            'size' => 7,
-                                                            'posvals' => $language_values ),
+                 '$provider_uri' => array( 'name' => _("Provider Link URI"),
+                                           'type' => SMOPT_TYPE_STRING ),
+                 '$provider_name' => array( 'name' => _("Provider Name"),
+                                            'type' => SMOPT_TYPE_STRING ),
                  '$frame_top' => array( 'name' => _("Top Frame"),
                                         'type' => SMOPT_TYPE_STRING,
                                         'size' => 40,
@@ -102,14 +104,27 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                                    'uw' => _("University of Washington's IMAP server"),
                                                                    'exchange' => _("Microsoft Exchange IMAP server"),
                                                                    'courier' => _("Courier IMAP server"),
+                                                                   'macosx' => _("Mac OS X Mailserver"),
+                                                                   'hmailserver' => _("hMailServer IMAP server"),
                                                                    'other' => _("Not one of the above servers") ) ),
                  '$optional_delimiter' => array( 'name' => _("IMAP Folder Delimiter"),
                                                  'type' => SMOPT_TYPE_STRING,
-                                                 'comment' => _("Use \"detect\" to auto-detect."),
+                                                 'comment' => _("Use &quot;detect&quot; to auto-detect."),
                                                  'size' => 10,
                                                  'default' => 'detect' ),
-                 '$useSendmail' => array( 'name' => _("Use Sendmail"),
-                                          'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$use_imap_tls' => array( 'name' => _("Use TLS for IMAP Connections"),
+                                           'type' => SMOPT_TYPE_BOOLEAN,
+                                           'comment' => _("Requires PHP 4.3.x! Experimental."),
+                                           'default' => false ),
+                 '$imap_auth_mech' => array( 'name' => _("IMAP Authentication Type"),
+                                             'type' => SMOPT_TYPE_STRLIST,
+                                             'posvals' => array('login' => _("IMAP login"),
+                                                                'cram-md5' => 'CRAM-MD5',
+                                                                'digest-md5' => 'DIGEST-MD5'),
+                                             'default' => 'login' ),
+                 '$useSendmail' => array( 'name' => _("Use Sendmail Binary"),
+                                          'type' => SMOPT_TYPE_BOOLEAN,
+                                          'comment' => _("Choose &quot;no&quot; for SMTP") ),
                  '$sendmail_path' => array( 'name' => _("Sendmail Path"),
                                             'type' => SMOPT_TYPE_STRING,
                                             'size' => 40 ),
@@ -118,12 +133,22 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                 'size' => 40 ),
                  '$smtpPort' => array( 'name' => _("SMTP Server Port"),
                                        'type' => SMOPT_TYPE_INTEGER ),
-                 '$use_authenticated_smtp' => array( 'name' => _("Authenticated SMTP"),
-                                                     'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$use_smtp_tls' => array( 'name' => _("Use TLS for SMTP Connections"),
+                                           'type' => SMOPT_TYPE_BOOLEAN,
+                                           'comment' => _("Requires PHP 4.3.x! Experimental."),
+                                           'default' => false ),
+                 '$smtp_auth_mech' => array( 'name' => _("SMTP Authentication Type"),
+                                             'type' => SMOPT_TYPE_STRLIST,
+                                             'posvals' => array('none' => _("No SMTP auth"),
+                                                                'login' => _("Login (plain text)"),
+                                                                'cram-md5' => 'CRAM-MD5',
+                                                                'digest-md5' => 'DIGEST-MD5'),
+                                             'default' => 'none'),
+                 '$pop_before_smtp' => array( 'name' => _("POP3 Before SMTP?"),
+                                              'type' => SMOPT_TYPE_BOOLEAN,
+                                              'default' => false ),
                  '$invert_time' => array( 'name' => _("Invert Time"),
                                           'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$default_use_mdn' => array( 'name' => _("Use Confirmation Flags"),
-                                              'type' => SMOPT_TYPE_BOOLEAN ),                                          
                  /* --------------------------------------------------------*/
                  'Group3' => array( 'name' => _("Folders Defaults"),
                                     'type' => SMOPT_TYPE_TITLE ),
@@ -168,29 +193,19 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                                        SMPREF_UNSEEN_TOTAL => _("Unseen and Total") ) ),
                  '$auto_create_special' => array( 'name' => _("Auto Create Special Folders"),
                                                   'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$default_use_javascript_addr_book' => array( 'name' => _("Default Javascript Adrressbook"),
-                                                  'type' => SMOPT_TYPE_BOOLEAN ),
                  '$delete_folder' => array( 'name' => _("Auto delete folders"),
                                             'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$noselect_fix_enable' => array( 'name' => _("Enable /NoSelect folder fix"),
+                                                  'type' => SMOPT_TYPE_BOOLEAN,
+                                                  'default' => false),
                  /* --------------------------------------------------------*/
                  'Group4' => array( 'name' => _("General Options"),
                                     'type' => SMOPT_TYPE_TITLE ),
-                 '$default_charset' => array( 'name' => _("Default Charset"),
-                                              'type' => SMOPT_TYPE_STRLIST,
-                                              'posvals' => array( 'iso_8859_1' => 'iso_8859_1',
-                                                                  'iso_8859_2' => 'iso_8859_2',
-                                                                  'iso_8859_7' => 'iso_8859_7',
-                                                                  'iso_8859_15' => 'iso_8859_15',
-                                                                  'iso_8859_15' => 'iso_8859_15',
-                                                                  'ns_4551_1' => 'ns_4551_1',
-                                                                  'koi8-r' => 'koi8-r',
-                                                                  'euc-KR' => 'euc-KR',
-                                                                  'windows-1251' => 'windows-1251' ) ),
                  '$data_dir' => array( 'name' => _("Data Directory"),
-                                       'type' => SMOPT_TYPE_STRING,
+                                       'type' => SMOPT_TYPE_PATH,
                                        'size' => 40 ),
                  '$attachment_dir' => array( 'name' => _("Temp Directory"),
-                                             'type' => SMOPT_TYPE_STRING,
+                                             'type' => SMOPT_TYPE_PATH,
                                              'size' => 40 ),
                  '$dir_hash_level' => array( 'name' => _("Hash Level"),
                                              'type' => SMOPT_TYPE_NUMLIST,
@@ -208,12 +223,26 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                     'type' => SMOPT_TYPE_BOOLEAN ),
                  '$hide_sm_attributions' => array( 'name' => _("Hide SM attributions"),
                                                    'type' => SMOPT_TYPE_BOOLEAN ),
-                 'default_use_mdn' => array( 'name' => _("Enable use of delivery receipts"),
+                 '$default_use_mdn' => array( 'name' => _("Enable use of delivery receipts"),
                                              'type' => SMOPT_TYPE_BOOLEAN ),
                  '$edit_identity' => array( 'name' => _("Allow editing of identities"),
                                             'type' => SMOPT_TYPE_BOOLEAN ),
                  '$edit_name' => array( 'name' => _("Allow editing of full name"),
                                         'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$allow_server_sort' => array( 'name' => _("Use server-side sorting"),
+                                                'type' => SMOPT_TYPE_BOOLEAN,
+                                                'default' => false ),
+                 '$allow_thread_sort' => array( 'name' => _("Use server-side thread sorting"),
+                                                'type' => SMOPT_TYPE_BOOLEAN,
+                                                'default' => false ),
+                 '$allow_charset_search' => array( 'name' => _("Allow server charset search"),
+                                                   'type' => SMOPT_TYPE_BOOLEAN,
+                                                   'default' => false ),
+                 '$uid_support' => array( 'name' => _("UID support"),
+                                          'type' => SMOPT_TYPE_BOOLEAN,
+                                          'default' => false ),
+                 '$session_name' => array( 'name' => _("PHP session name"),
+                                           'type' => SMOPT_TYPE_HIDDEN ),
                  /* --------------------------------------------------------*/
                  'Group5' => array( 'name' => _("Message of the Day"),
                                     'type' => SMOPT_TYPE_TITLE ),
@@ -249,17 +278,70 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                              'type' => SMOPT_TYPE_STRING,
                                              'size' => 40,
                                              'default' => 'prefval' ),
+                 '$addrbook_global_dsn' => array( 'name' => _("Global address book DSN"),
+                                           'type' => SMOPT_TYPE_STRING,
+                                           'size' => 40 ),
+                 '$addrbook_global_table' => array( 'name' => _("Global address book table"),
+                                             'type' => SMOPT_TYPE_STRING,
+                                             'size' => 40,
+                                             'default' => 'global_abook' ),
+                 '$addrbook_global_writeable' => array( 'name' => _("Allow writing into global address book"),
+                                            'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$addrbook_global_listing' => array( 'name' => _("Allow listing of global address book"),
+                                            'type' => SMOPT_TYPE_BOOLEAN ),
+                 /* ---- Language settings ---- */
+                 'Group9' => array( 'name' => _("Language settings"),
+                                    'type' => SMOPT_TYPE_TITLE ),
+                 '$squirrelmail_default_language' => array( 'name' => _("Default Language"),
+                                                            'type' => SMOPT_TYPE_STRLIST,
+                                                            'size' => 7,
+                                                            'posvals' => $language_values ),
+                 '$default_charset' => array( 'name' => _("Default Charset"),
+                                              'type' => SMOPT_TYPE_STRLIST,
+                                              'posvals' => array( 'iso-8859-1' => 'iso-8859-1',
+                                                                  'iso-8859-2' => 'iso-8859-2',
+                                                                  'iso-8859-7' => 'iso-8859-7',
+                                                                  'iso-8859-9' => 'iso-8859-9',
+                                                                  'iso-8859-15' => 'iso-8859-15',
+                                                                  'utf-8' => 'utf-8',
+                                                                  'koi8-r' => 'koi8-r',
+                                                                  'euc-kr' => 'euc-kr',
+                                                                  'big5' => 'big5',
+                                                                  'gb2312' => 'gb2312',
+                                                                  'tis-620' => 'tis-620',
+                                                                  'windows-1251' => 'windows-1251',
+                                                                  'windows-1255' => 'windows-1255',
+                                                                  'windows-1256' => 'windows-1256',
+                                                                  'iso-2022-jp' => 'iso-2022-jp' ) ),
+                  '$lossy_encoding'  => array( 'name' => _("Enable lossy encoding"),
+                                               'type' => SMOPT_TYPE_BOOLEAN ),
+                 /* ---- Settings of address books ---- */
+                 'Group10' => array( 'name' => _("Address Books"),
+                                     'type' => SMOPT_TYPE_TITLE ),
+                 '$default_use_javascript_addr_book' => array( 'name' => _("Default Javascript Addressbook"),
+                                                  'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$abook_global_file' => array( 'name' => _("Global address book file"),
+                                                  'type' => SMOPT_TYPE_STRING ),
+                 '$abook_global_file_writeable' => array( 'name' => _("Allow writing into global address book file"),
+                                                  'type' => SMOPT_TYPE_BOOLEAN ),
                  /* --------------------------------------------------------*/
                  'Group7' => array( 'name' => _("Themes"),
                                     'type' => SMOPT_TYPE_TITLE ),
                  '$theme_css' => array( 'name' => _("Style Sheet URL (css)"),
-                                        'type' => SMOPT_TYPE_STRING,
+                                        'type' => SMOPT_TYPE_PATH,
                                         'size' => 40 ),
+                 '$theme_default' => array( 'name' => _("Default theme"),
+                                            'type' => SMOPT_TYPE_INTEGER,
+                                            'default' => 0,
+                                            'comment' => _("Use index number of theme") ),
+                 /* ---- Group8 is for plugins ---- */
                  /* --------------------------------------------------------*/
-                 '$config_use_color' => array(  'name' => '',
-                                                'type' => SMOPT_TYPE_HIDDEN )
+                 '$config_use_color' => array( 'name' => '',
+                                               'type' => SMOPT_TYPE_HIDDEN ),
+                 '$no_list_for_subscribe' => array( 'name' => '',
+                                                    'type' => SMOPT_TYPE_HIDDEN ),
                  /* --------------------------------------------------------*/
 
                );
 
-?>
+?>
\ No newline at end of file
