@@ -1,16 +1,24 @@
 <?php
-
 /**
- * Administrator Plugin
+ * Administrator Plugin - Options Page
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * This script creates separate page, that allows to review and modify
+ * SquirrelMail configuration file.
  *
- * Philippe Mingo
- *
- * $Id: options.php,v 1.21 2002/02/13 12:40:57 philippe_mingo Exp $
+ * @version $Id: options.php,v 1.32.2.7 2004/12/27 15:03:48 kink Exp $
+ * @author Philippe Mingo
+ * @copyright (c) 1999-2005 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @package plugins
+ * @subpackage administrator
  */
 
+/**
+ * parse the config file
+ *
+ * @param string $cfg_file
+ * @access private
+ */
 function parseConfig( $cfg_file ) {
 
     global $newcfg;
@@ -36,7 +44,7 @@ function parseConfig( $cfg_file ) {
                 break;
             case 'K':
                 // Key detect
-                if( $line{$j} == ' ' ) {
+                if ( $line{$j} == ' ' ) {
                     $mode = '=';
                 } else {
                     $key .= $line{$j};
@@ -127,23 +135,96 @@ function parseConfig( $cfg_file ) {
             }
         }
     }
-
 }
 
+/**
+ * Change paths containing SM_PATH to admin-friendly paths
+ * relative to the config dir, i.e.:
+ *    ''                          --> <empty string>
+ *    SM_PATH . 'images/logo.gif' --> ../images/logo.gif
+ *    '/absolute/path/logo.gif'   --> /absolute/path/logo.gif
+ *    'http://whatever/'          --> http://whatever
+ *  Note removal of quotes in returned value
+ *  
+ * @param string $old_path path that has to be converted
+ * @return string new path
+ * @access private
+ */
+function change_to_rel_path($old_path) {
+    $new_path = str_replace("SM_PATH . '", "../", $old_path); 
+    $new_path = str_replace("../config/","", $new_path);
+    $new_path = str_replace("'","", $new_path);
+    return $new_path;
+}
+
+/**
+ * Change relative path (relative to config dir) to 
+ *  internal SM_PATH, i.e.:
+ *     empty_string            --> ''
+ *     ../images/logo.gif      --> SM_PATH . 'images/logo.gif'
+ *     images/logo.gif         --> SM_PATH . 'config/images/logo.gif'
+ *     /absolute/path/logo.gif --> '/absolute/path/logo.gif'
+ *     http://whatever/        --> 'http://whatever'
+ *  
+ * @param string $old_path path that has to be converted
+ * @return string new path
+ * @access private
+*/     
+function change_to_sm_path($old_path) {
+    if ( $old_path === '' || $old_path == "''" ) {
+        return "''";
+    } elseif ( preg_match("/^(\/|http)/", $old_path) ) {
+        return "'" . $old_path . "'";
+    } elseif ( preg_match("/^(\$|SM_PATH)/", $old_path) ) {
+        return $old_path;
+    }
+   
+    $new_path = '';
+    $rel_path = explode("../", $old_path);
+    if ( count($rel_path) > 2 ) {
+        // Since we're relative to the config dir, 
+        // more than 1 ../ puts us OUTSIDE the SM tree.
+        // get full path to config.php, then pop the filename
+        $abs_path = explode('/', realpath (SM_PATH . 'config/config.php'));
+        array_pop ($abs_path); 
+        foreach ( $rel_path as $subdir ) {
+            if ( $subdir === '' ) {
+                array_pop ($abs_path);
+            } else {
+                array_push($abs_path, $subdir);
+            }
+        }
+        foreach ($abs_path as $subdir) {
+            $new_path .= $subdir . '/';
+        }
+        $new_path = "'$new_path'";
+    } elseif ( count($rel_path) > 1 ) {
+        // we're within the SM tree, prepend SM_PATH
+        $new_path = str_replace('../',"SM_PATH . '", $old_path . "'");
+    } else {
+        // Last, if it's a relative path without a .. prefix, 
+        // we're somewhere within the config dir, so prepend
+        //  SM_PATH . 'config/  
+        $new_path = "SM_PATH . 'config/" . $old_path . "'";
+    }
+    return $new_path;
+}
+
+
 /* ---------------------- main -------------------------- */
 
-chdir('..');
-require_once('../src/validate.php');
-require_once('../functions/page_header.php');
-require_once('../functions/imap.php');
-require_once('../src/load_prefs.php');
-require_once('../plugins/administrator/defines.php');
-require_once('../plugins/administrator/auth.php');
+/** @ignore */
+define('SM_PATH','../../');
 
-GLOBAL $data_dir, $username;
+/* SquirrelMail required files. */
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'plugins/administrator/defines.php');
+require_once(SM_PATH . 'plugins/administrator/auth.php');
+
+global $data_dir, $username;
 
 if ( !adm_check_user() ) {
-    header("Location: ../../src/options.php") ;
+    header('Location: ' . SM_PATH . 'src/options.php') ;
     exit;
 }
 
@@ -155,8 +236,8 @@ foreach ( $defcfg as $key => $def ) {
     $newcfg[$key] = '';
 }
 
-$cfgfile = '../config/config.php';
-parseConfig( '../config/config_default.php' );
+$cfgfile = SM_PATH . 'config/config.php';
+parseConfig( SM_PATH . 'config/config_default.php' );
 parseConfig( $cfgfile );
 
 $colapse = array( 'Titles' => 'off',
@@ -167,23 +248,31 @@ $colapse = array( 'Titles' => 'off',
                   'Group5' => getPref($data_dir, $username, 'adm_Group5', 'on' ),
                   'Group6' => getPref($data_dir, $username, 'adm_Group6', 'on' ),
                   'Group7' => getPref($data_dir, $username, 'adm_Group7', 'on' ),
-                  'Group8' => getPref($data_dir, $username, 'adm_Group8', 'on' ) );
-
-if ( isset( $switch ) ) {
+                  'Group8' => getPref($data_dir, $username, 'adm_Group8', 'on' ),
+                  'Group9' => getPref($data_dir, $username, 'adm_Group9', 'on' ),
+                  'Group10' => getPref($data_dir, $username, 'adm_Group10', 'on' ) );
 
+/* look in $_GET array for 'switch' */
+if ( sqgetGlobalVar('switch', $switch, SQ_GET) ) {
     if ( $colapse[$switch] == 'on' ) {
-       $colapse[$switch] = 'off';
+        $colapse[$switch] = 'off';
     } else {
-       $colapse[$switch] = 'on';
+        $colapse[$switch] = 'on';
     }
     setPref($data_dir, $username, "adm_$switch", $colapse[$switch] );
-
 }
 
-echo "<form action=options.php method=post name=options>" .
-    "<br><center><table width=95% bgcolor=\"$color[5]\"><tr><td>".
-    "<table width=100% cellspacing=0 bgcolor=\"$color[4]\">" ,
-    "<tr bgcolor=\"$color[5]\"><th colspan=2>" . _("Configuration Administrator") . "</th></tr>";
+echo '<form action="options.php" method="post" name="options">' .
+     '<center><table width="95%" bgcolor="'.$color[5].'"><tr><td>'.
+     '<table width="100%" cellspacing="0" bgcolor="'.$color[4].'">'.
+     '<tr bgcolor="'.$color[5].'"><th colspan="2">'.
+     _("Configuration Administrator").'</th></tr>'.
+     '<tr bgcolor="'.$color[5].'"><td colspan="2" align="center"><small>'.
+     _("Note: it is recommended that you configure your system using conf.pl, and not this plugin. conf.pl contains additional information regarding the purpose of variables and appropriate values, as well as additional verification steps.").
+     '<br />'.
+     _("Run or consult conf.pl should you run into difficulty with your configuration.").
+     '</small></td></tr>';
+
 
 $act_grp = 'Titles';  /* Active group */
 
@@ -224,7 +313,7 @@ foreach ( $newcfg as $k => $v ) {
         $type = SMOPT_TYPE_LDAP;
     }
 
-    if( $type == SMOPT_TYPE_TITLE || $colapse[$act_grp] == 'off' ) {
+    if ( $type == SMOPT_TYPE_TITLE || $colapse[$act_grp] == 'off' ) {
 
         switch ( $type ) {
         case SMOPT_TYPE_LDAP:
@@ -235,7 +324,7 @@ foreach ( $newcfg as $k => $v ) {
         case SMOPT_TYPE_EXTERNAL:
             echo "<tr><td>$name</td><td><b>" .
                  $defcfg[$k]['value'] .
-                 "</b></td></tr>";
+                 '</b></td></tr>';
             break;
         case SMOPT_TYPE_TITLE:
             if ( $colapse[$k] == 'on' ) {
@@ -243,9 +332,9 @@ foreach ( $newcfg as $k => $v ) {
             } else {
                 $sw = '(-)';
             }
-            echo "<tr bgcolor=\"$color[0]\"><th colspan=2>" .
-                 "<a href=options.php?switch=$k STYLE=\"text-decoration:none\"><b>$sw</b> </a>" .
-                 "$name</th></tr>";
+            echo '<tr bgcolor="'.$color[0].'"><th colspan="2">'.
+                 "<a href=\"options.php?switch=$k\" style=\"text-decoration:none\">".
+                 '<b>'.$sw.'</b></a> '.$name.'</th></tr>';
             $act_grp = $k;
             break;
         case SMOPT_TYPE_COMMENT:
@@ -259,20 +348,20 @@ foreach ( $newcfg as $k => $v ) {
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_INTEGER:
-            if ( isset( $HTTP_POST_VARS[$e] ) ) {
-                $v = intval( $HTTP_POST_VARS[$e] );
+            /* look for variable $e in POST, fill into $v */
+            if ( sqgetGlobalVar($e, $v, SQ_POST) ) {
+                $v = intval( $v );
                 $newcfg[$k] = $v;
             }
             echo "<tr><td>$name</td><td>".
-                 "<input size=10 name=\"adm_$n\" value=\"$v\">";
+                 "<input size=\"10\" name=\"adm_$n\" value=\"$v\" />";
             if ( isset( $defcfg[$k]['comment'] ) ) {
                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_NUMLIST:
-            if ( isset( $HTTP_POST_VARS[$e] ) ) {
-                $v = $HTTP_POST_VARS[$e];
+            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
                 $newcfg[$k] = $v;
             }
             echo "<tr><td>$name</td><td>";
@@ -280,7 +369,7 @@ foreach ( $newcfg as $k => $v ) {
             foreach ( $defcfg[$k]['posvals'] as $kp => $vp ) {
                 echo "<option value=\"$kp\"";
                 if ( $kp == $v ) {
-                    echo ' selected';
+                    echo ' selected="selected"';
                 }
                 echo ">$vp</option>";
             }
@@ -291,8 +380,8 @@ foreach ( $newcfg as $k => $v ) {
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_STRLIST:
-            if ( isset( $HTTP_POST_VARS[$e] ) ) {
-                $v = '"' . $HTTP_POST_VARS[$e] . '"';
+            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
+                $v = '"' . $v . '"';
                 $newcfg[$k] = $v;
             }
             echo "<tr><td>$name</td><td>".
@@ -300,7 +389,7 @@ foreach ( $newcfg as $k => $v ) {
             foreach ( $defcfg[$k]['posvals'] as $kp => $vp ) {
                 echo "<option value=\"$kp\"";
                 if ( $kp == substr( $v, 1, strlen( $v ) - 2 ) ) {
-                    echo ' selected';
+                    echo ' selected="selected"';
                 }
                 echo ">$vp</option>";
             }
@@ -312,20 +401,20 @@ foreach ( $newcfg as $k => $v ) {
             break;
 
         case SMOPT_TYPE_TEXTAREA:
-            if ( isset( $HTTP_POST_VARS[$e] ) ) {
-                $v = '"' . $HTTP_POST_VARS[$e] . '"';
+            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
+                $v = '"' . $v . '"';
                 $newcfg[$k] = str_replace( "\n", '', $v );
             }
-            echo "<tr><td valign=top>$name</td><td>".
-                 "<textarea cols=\"$size\" name=\"adm_$n\">" . substr( $v, 1, strlen( $v ) - 2 ) . "</textarea>";
+            echo "<tr><td valign=\"top\">$name</td><td>".
+                 "<textarea cols=\"$size\" rows=\"4\" name=\"adm_$n\">" . substr( $v, 1, strlen( $v ) - 2 ) . "</textarea>";
             if ( isset( $defcfg[$k]['comment'] ) ) {
                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_STRING:
-            if ( isset( $HTTP_POST_VARS[$e] ) ) {
-                $v = '"' . $HTTP_POST_VARS[$e] . '"';
+            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
+                $v = '"' . $v . '"';
                 $newcfg[$k] = $v;
             }
             if ( $v == '""' && isset( $defcfg[$k]['default'] ) ) {
@@ -333,34 +422,49 @@ foreach ( $newcfg as $k => $v ) {
                 $newcfg[$k] = $v;
             }
             echo "<tr><td>$name</td><td>".
-                 "<input size=\"$size\" name=\"adm_$n\" value=\"" . substr( $v, 1, strlen( $v ) - 2 ) . "\">";
+                 "<input size=\"$size\" name=\"adm_$n\" value=\"" . substr( $v, 1, strlen( $v ) - 2 ) . '" />';
             if ( isset( $defcfg[$k]['comment'] ) ) {
                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_BOOLEAN:
-            if ( isset( $HTTP_POST_VARS[$e] ) ) {
-                $v = $HTTP_POST_VARS[$e];
+            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
                 $newcfg[$k] = $v;
             } else {
                 $v = strtoupper( $v );
             }
             if ( $v == 'TRUE' ) {
-                $ct = ' checked';
+                $ct = ' checked="checked"';
                 $cf = '';
             } else {
                 $ct = '';
-                $cf = ' checked';
+                $cf = ' checked="checked"';
             }
             echo "<tr><td>$name</td><td>" .
-                 "<INPUT$ct type=radio NAME=\"adm_$n\" value=\"TRUE\">" . _("Yes") .
-                 "<INPUT$cf type=radio NAME=\"adm_$n\" value=\"FALSE\">" . _("No");
+                 "<input$ct type=\"radio\" name=\"adm_$n\" value=\"TRUE\" />" . _("Yes") .
+                 "<input$cf type=\"radio\" name=\"adm_$n\" value=\"FALSE\" />" . _("No");
             if ( isset( $defcfg[$k]['comment'] ) ) {
                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
             echo "</td></tr>\n";
             break;
+        case SMOPT_TYPE_PATH:
+            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
+               $v = change_to_sm_path($v);
+               $newcfg[$k] = $v;
+            }
+            if ( $v == "''" && isset( $defcfg[$k]['default'] ) ) {
+               $v = change_to_sm_path($defcfg[$k]['default']);
+               $newcfg[$k] = $v;
+            }
+            echo "<tr><td>$name</td><td>".
+                 "<input size=\"$size\" name=\"adm_$n\" value=\"" . change_to_rel_path($v) . '" />';
+            if ( isset( $defcfg[$k]['comment'] ) ) {
+                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
+            }
+            echo "</td></tr>\n";
+            break;
         default:
             echo "<tr><td>$name</td><td>" .
                  "<b><i>$v</i></b>";
@@ -370,7 +474,6 @@ foreach ( $newcfg as $k => $v ) {
             echo "</td></tr>\n";
         }
     }
-
 }
 
 /* Special Themes Block */
@@ -382,25 +485,26 @@ if ( $colapse['Group7'] == 'off' ) {
     while ( isset( $newcfg["\$theme[$i]['NAME']"] ) ) {
         $k1 = "\$theme[$i]['NAME']";
         $e1 = "theme_name_$i";
-        if ( isset( $HTTP_POST_VARS[$e1] ) ) {
-            $v1 = '"' . $HTTP_POST_VARS[$e1] . '"';
+        if (  sqgetGlobalVar($e, $v1, SQ_POST) ) {
+            $v1 = '"' . str_replace( '\"', '"', $v1 ) . '"';
+            $v1 = '"' . str_replace( '"', '\"', $v1 ) . '"';
             $newcfg[$k1] = $v1;
         } else {
             $v1 = $newcfg[$k1];
         }
         $k2 = "\$theme[$i]['PATH']";
         $e2 = "theme_path_$i";
-        if ( isset( $HTTP_POST_VARS[$e2] ) ) {
-            $v2 = '"' . $HTTP_POST_VARS[$e2] . '"';
+        if (  sqgetGlobalVar($e, $v2, SQ_POST) ) {
+            $v2 = change_to_sm_path($v2);
             $newcfg[$k2] = $v2;
         } else {
             $v2 = $newcfg[$k2];
         }
         $name = substr( $v1, 1, strlen( $v1 ) - 2 );
-        $path = substr( $v2, 1, strlen( $v2 ) - 2 );
+        $path = change_to_rel_path($v2);
         echo '<tr>'.
-             "<td align=right>$i. <input name=\"$e1\" value=\"$name\" size=30></td>".
-             "<td><input name=\"$e2\" value=\"$path\" size=40></td>".
+             "<td align=\"right\">$i. <input name=\"$e1\" value=\"$name\" size=\"30\" /></td>".
+             "<td><input name=\"$e2\" value=\"$path\" size=\"40\" /></td>".
              "</tr>\n";
         $i++;
 
@@ -413,123 +517,113 @@ if ( $colapse['Group8'] == 'on' ) {
 } else {
     $sw = '(-)';
 }
-echo "<tr bgcolor=\"$color[0]\"><th colspan=2>" .
-     "<a href=options.php?switch=Group8 STYLE=\"text-decoration:none\"><b>$sw</b> </a>" .
-     _("Plugins") . '</th></tr>';
+echo '<tr bgcolor="'.$color[0].'"><th colspan="2">'.
+     '<a href="options.php?switch=Group8" style="text-decoration:none"><b>'.
+     $sw.'</b></a> '._("Plugins").'</th></tr>';
 
-if( $colapse['Group8'] == 'off' ) {
+if ( $colapse['Group8'] == 'off' ) {
 
-    $fd = opendir( '../plugins/' );
-    $op_plugin = array();
-    $p_count = 0;
-    while (false!==($file = readdir($fd))) {
-        if ($file != '.' && $file != '..' && $file != 'CVS' ) {
-            if ( filetype( $file ) == 'dir' ) {
+    $plugpath = SM_PATH . 'plugins/';
+    if ( file_exists($plugpath) ) {
+        $fd = opendir( $plugpath );
+        $op_plugin = array();
+        $p_count = 0;
+        while (false !== ($file = readdir($fd))) {
+            if ($file != '.' && $file != '..' && $file != 'CVS' && is_dir($plugpath . $file) ) {
                 $op_plugin[] = $file;
                 $p_count++;
             }
         }
-    }
-    closedir($fd);
-    asort( $op_plugin );
+        closedir($fd);
+        asort( $op_plugin );
 
-    /* Lets get the plugins that are active */
-    $plugins = array();
-    if ( isset( $HTTP_POST_VARS['plg'] ) ) {
-        foreach ( $op_plugin as $plg ) {
-            if ( isset( $HTTP_POST_VARS["plgs_$plg"] ) &&
-                 $HTTP_POST_VARS["plgs_$plg"] == 'on' ) {
-                $plugins[] = $plg;
+        /* Lets get the plugins that are active */
+        $plugins = array();
+        if (  sqgetGlobalVar('plg', $v, SQ_POST) ) {
+            foreach ( $op_plugin as $plg ) {
+                if (  sqgetGlobalVar("plgs_$plg", $v, SQ_POST) && $v == 'on' ) {
+                    $plugins[] = $plg;
+                }
+            }
+            $i = 0;
+            foreach ( $plugins as $plg ) {
+                $k = "\$plugins[$i]";
+                $newcfg[$k] = "'$plg'";
+                $i++;
+            }
+            while ( isset( $newcfg["\$plugins[$i]"] ) ) {
+                $k = "\$plugins[$i]";
+                $newcfg[$k] = '';
+                $i++;
+            }
+        } else {
+            $i = 0;
+            while ( isset( $newcfg["\$plugins[$i]"] ) ) {
+                $k = "\$plugins[$i]";
+                $v = $newcfg[$k];
+                $plugins[] = substr( $v, 1, strlen( $v ) - 2 );
+                $i++;
             }
         }
-        $i = 0;
-        foreach ( $plugins as $plg ) {
-            $k = "\$plugins[$i]";
-            $newcfg[$k] = "'$plg'";
-            $i++;
-        }
-        while ( isset( $newcfg["\$plugins[$i]"] ) ) {
-            $k = "\$plugins[$i]";
-            $newcfg[$k] = '';
-            $i++;
+        echo '<tr><td colspan="2"><input type="hidden" name="plg" value="on" /><center><table>';
+        foreach ( $op_plugin as $plg ) {
+            if ( in_array( $plg, $plugins ) ) {
+                $sw = ' checked="checked"';
+            } else {
+                $sw = '';
+            }
+            echo '<tr><td>';
+            if (file_exists(SM_PATH . "plugins/$plg/README")) {
+                echo "<a href=\"../$plg/README\" target=\"_blank\">$plg</a>";
+            } else {
+                echo $plg;
+            }
+            echo "</td>\n".
+                 "<td><input$sw type=\"checkbox\" name=\"plgs_$plg\" /></td>".
+                 "</tr>\n";
         }
+        echo '</table></center></td></tr>';
     } else {
-        $i = 0;
-        while ( isset( $newcfg["\$plugins[$i]"] ) ) {
-            $k = "\$plugins[$i]";
-            $v = $newcfg[$k];
-            $plugins[] = substr( $v, 1, strlen( $v ) - 2 );
-            $i++;
-        }
+        echo '<tr><td colspan="2" align="center">'.
+             sprintf(_("Plugin directory could not be found: %s"), $plugpath).
+             "</td></tr>\n";
     }
-    echo "<tr><td colspan=2><input type=hidden name=plg value=on><center><table><tr><td>";
-    foreach ( $op_plugin as $plg ) {
-        if ( in_array( $plg, $plugins ) ) {
-            $sw = ' checked';
-        } else {
-            $sw = '';
-        }
-        echo '<tr>' .
-             "<td>$plg</td><td><input$sw type=checkbox name=plgs_$plg></td>".
-             "</tr>\n";
-    }
-    echo '</td></tr></table>';
-
 }
-echo "<tr bgcolor=\"$color[5]\"><th colspan=2><input value=\"" .
-     _("Change Settings") . "\" type=submit></th></tr>" ,
-     '</table></td></tr></table></form>';
+echo '<tr bgcolor="'.$color[5].'"><th colspan="2"><input value="'.
+     _("Change Settings").'" type="submit" /><br />'.
+     '<a href="'.SM_PATH.'src/configtest.php" target="_blank">'.
+     _("Test Configuration")."</a></th></tr>\n".
+     '</table></td></tr></table></center></form>';
 
 /*
     Write the options to the file.
 */
 
-if( $fp = @fopen( $cfgfile, 'w' ) ) {
-    fwrite( $fp, "<?PHP\n".
-            "/**\n".
-            " * SquirrelMail Configuration File\n".
-            " * Created using the Administrator Plugin\n".
-            " */\n" );
+if ( $fp = @fopen( $cfgfile, 'w' ) ) {
+    fwrite( $fp, "<?php\n".
+    "/**\n".
+    " * SquirrelMail Configuration File\n".
+    " * Created using the Administrator Plugin\n".
+    " */\n".
+    "\n".
+    "global \$version;\n" );
 
-    /*
-    fwrite( $fp, 'GLOBAL ' );
-    $not_first = FALSE;
     foreach ( $newcfg as $k => $v ) {
-    if ( $k{0} == '$' ) {
-            if( $i = strpos( $k, '[' ) ) {
-            if( strpos( $k, '[0]' ) ) {
-                    if( $not_first ) {
-                    fwrite( $fp, ', ' );
-                    }
-                    fwrite( $fp, substr( $k, 0, $i) );
-            }
-            } else {
-            if( $not_first ) {
-                    fwrite( $fp, ', ' );
-            }
-            fwrite( $fp, $k );
-            }
-            $not_first = TRUE;
-    }
-    }
-    fwrite( $fp, ";\n" );
-    */
-    foreach ( $newcfg as $k => $v ) {
-    if ( $k{0} == '$' && $v <> '' ) {
+        if ( $k{0} == '$' && $v <> '' || is_int($v)) {
             if ( substr( $k, 1, 11 ) == 'ldap_server' ) {
-            $v = substr( $v, 0, strlen( $v ) - 1 ) . "\n)";
-            $v = str_replace( 'array(', "array(\n\t", $v );
-            $v = str_replace( "',", "',\n\t", $v );
+                $v = substr( $v, 0, strlen( $v ) - 1 ) . "\n)";
+                $v = str_replace( 'array(', "array(\n\t", $v );
+                $v = str_replace( "',", "',\n\t", $v );
             }
             fwrite( $fp, "$k = $v;\n" );
-    }
+        }
     }
     fwrite( $fp, '?>' );
     fclose( $fp );
 } else {
-    echo '<font size=+1><br>'.
+    echo '<br /><p align="center"><big>'.
          _("Config file can't be opened. Please check config.php.").
-         '</font>';
+         '</big></p>';
 }
-
-?>
\ No newline at end of file
+?>
+</body></html>
\ No newline at end of file
