@@ -1,13 +1,16 @@
 <?php
-/*
- *  calendar_data.php
+
+/**
+ * calendar_data.php
  *
- *  Copyright (c) 2001 Michal Szczotka <michal@tuxy.org>
- *  Licensed under the GNU GPL. For full terms see the file COPYING.
+ * Copyright (c) 2002-2005 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- *  functions to operate on calendar data files.
+ * Originally contrubuted by Michal Szczotka <michal@tuxy.org>
  *
- * $Id: calendar_data.php,v 1.3 2002/02/02 02:17:05 philippe_mingo Exp $
+ * functions to operate on calendar data files.
+ *
+ * $Id: calendar_data.php,v 1.7.2.8 2004/12/27 15:03:49 kink Exp $
  */
 
 // this is array that contains all events
@@ -32,18 +35,25 @@ function readcalendardata() {
             while ($fdata = fgetcsv ($fp, 4096, '|')) {
                 $calendardata[$fdata[0]][$fdata[1]] = array( 'length' => $fdata[2],
                                                             'priority' => $fdata[3],
-                                                            'title' => $fdata[4],
-                                                            'message' => $fdata[5],
+                                                            'title' => htmlspecialchars($fdata[4],ENT_NOQUOTES),
+                                                            'message' => htmlspecialchars($fdata[5],ENT_NOQUOTES),
                                                             'reminder' => $fdata[6] );
             }
             fclose ($fp);
+            // this is to sort the events within a day on starttime
+            $new_calendardata = array();
+            foreach($calendardata as $day => $data) {
+                ksort($data, SORT_NUMERIC);
+                $new_calendardata[$day] = $data;
+            }
+            $calendardata = $new_calendardata;
         }
     }
 }
 
 //makes events persistant
 function writecalendardata() {
-    global $calendardata, $username, $data_dir, $year;
+    global $calendardata, $username, $data_dir, $year, $color;
 
     $filetmp = getHashedFile($username, $data_dir, "$username.$year.cal.tmp");
     $filename = getHashedFile($username, $data_dir, "$username.$year.cal");
@@ -53,11 +63,14 @@ function writecalendardata() {
             while ( $calbar = each ($calfoo['value'])) {
                 $calfoobar = $calendardata[$calfoo['key']][$calbar['key']];
                 $calstr = "$calfoo[key]|$calbar[key]|$calfoobar[length]|$calfoobar[priority]|$calfoobar[title]|$calfoobar[message]|$calfoobar[reminder]\n";
-                fwrite($fp, $calstr, 4096);
+                if(sq_fwrite($fp, $calstr, 4096) === FALSE) {
+			error_box(_("Could not write calendar file %s", "$username.$year.cal.tmp"), $color);
+		}
             }
 
         }
         fclose ($fp);
+        @unlink($filename);
         rename($filetmp,$filename);
     }
 }
@@ -110,4 +123,4 @@ function update_event($date, $time) {
 }
 
 
-?>
\ No newline at end of file
+?>
