@@ -7,38 +7,56 @@
  *   deletes or moves currently displayed message and displays
  *   next or previous message.
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: setup.php,v 1.8 2002/04/28 23:56:35 jmunro Exp $
+ * $Id: setup.php,v 1.23.2.7 2005/01/20 17:07:01 jangliss Exp $
+ * @package plugins
+ * @subpackage delete_move_next
  */
 
+/**
+ * Initialize the plugin
+ * @return void
+ */
 function squirrelmail_plugin_init_delete_move_next() {
     global $squirrelmail_plugin_hooks;
-    
+
     $squirrelmail_plugin_hooks['html_top']['delete_move_next'] = 'delete_move_next_action';
     $squirrelmail_plugin_hooks['right_main_after_header']['delete_move_next'] = 'delete_move_next_action';
     $squirrelmail_plugin_hooks['read_body_bottom']['delete_move_next'] = 'delete_move_next_read_b';
-    $squirrelmail_plugin_hooks['read_body_top']['delete_move_next'] = 'delete_move_next_read_t';
+    $squirrelmail_plugin_hooks['read_body_menu_bottom']['delete_move_next'] = 'delete_move_next_read_t';
     $squirrelmail_plugin_hooks['options_display_inside']['delete_move_next'] = 'delete_move_next_display_inside';
     $squirrelmail_plugin_hooks['options_display_save']['delete_move_next'] = 'delete_move_next_display_save';
     $squirrelmail_plugin_hooks['loading_prefs']['delete_move_next'] = 'delete_move_next_loading_prefs';
 }
 
-
 /* fixes the sort_array for the prev_del/next_del links when 
  * using server side sorting or thread sorting 
  */
 
 function fix_sort_array () {
     global $username, $data_dir, $allow_server_sort, $allow_thread_sort,
-    $mailbox, $imapConnection, $sort;
-    if ($allow_server_sort == true) {
-        $server_sort_array = sqimap_get_sort_order($imapConnection, $sort);
+    $thread_sort_messages, 
+    $mailbox, $imapConnection, $sort, $uid_support, $mbx_response;
+
+    // Got to grab this out of prefs, since it isn't saved from mailbox_view.php
+    if ($allow_thread_sort) {
+        $thread_sort_messages = getPref($data_dir, $username, "thread_$mailbox",0);
     }
-    $thread_sort_messages = getPref($username, $data_dir, "thread_$mailbox");
-    if ($allow_thread_sort == true && $thread_sort_messages == 1) {
-        $server_sort_array = get_thread_sort($imapConnection);
+
+    switch (true) {
+      case ($allow_thread_sort && $thread_sort_messages):
+          $server_sort_array = get_thread_sort($imapConnection);
+          break;
+      case ($allow_server_sort):
+          $server_sort_array = sqimap_get_sort_order($imapConnection, $sort, $mbx_response);
+          break;
+      case ($uid_support):
+          $server_sort_array = sqimap_get_php_sort_order($imapConnection, $mbx_response);
+          break;
+      default:
+          break;
     }
 }
 
@@ -53,67 +71,66 @@ function fix_sort_array () {
 
 function delete_move_del_arr_elem($arr, $index) {
     $tmp = array();
-    $lim = count($arr);
     $j = 0;
-    for ($i = 0; $i < $lim; $i++) {
-        if ($i != $index) {
-            $tmp[$j++] = $arr[$i];
-        }
+    foreach ($arr as $v) {
+        if ($j != $index) {
+           $tmp[] = $v;
+         }
+         $j++;
     }
     return $tmp;
 }
 
 function delete_move_show_msg_array() {
     global $msort, $msgs;
-    
     $keys = array_keys($msort);
     for ($i = 0; $i < count($keys); $i++) {
         echo '<p>key ' . $keys[$i] . ' msgid ' . $msgs[$keys[$i]]['ID'] . '</p>';
     }
 }
 
-
 function delete_move_expunge_from_all($id) {
-    global $msgs, $msort, $sort, $imapConnection, $mailbox;
-    
-    // delete_move_show_msg_array();
-    
+    global $msgs, $msort, $sort, $imapConnection, $mailbox, $uid_support;
     $delAt = -1;
-    for ($i = 0; $i < count($msort); $i++) {
-        if ($msgs[$i]['ID'] == $id) {
-            $delAt = $i;
-        } elseif ($msgs[$i]['ID'] > $id) {
-            $msgs[$i]['ID']--;
+
+    if(isset($msort) && count($msort) > 0) {
+        for ($i = 0; $i < count($msort); $i++) {
+            if ($msgs[$i]['ID'] == $id) {
+                $delAt = $i;
+            } elseif ($msgs[$i]['ID'] > $id) {
+                if (!$uid_support) {
+                   $msgs[$i]['ID']--;
+                }
+            }
         }
-    }
-    
-    $msgs = delete_move_del_arr_elem($msgs, $delAt);
-    $msort = delete_move_del_arr_elem($msort, $delAt);
-    
-    if ($sort < 6) {
-        if ($sort % 2) {
-            asort($msort);
-        } else {
-            arsort($msort);
+
+        $msgs = delete_move_del_arr_elem($msgs, $delAt);
+        $msort = delete_move_del_arr_elem($msort, $delAt);
+        if ($sort < 6) {
+            if ($sort % 2) {
+                asort($msort);
+            } else {
+                arsort($msort);
+            }
         }
+        sqsession_register($msgs, 'msgs');
+        sqsession_register($msort, 'msort');
     }
-    
+
     sqimap_mailbox_expunge($imapConnection, $mailbox, true);
 }
 
 function delete_move_next_action() {
 
-    global $PHP_SELF,
-           $delete_id, $move_id;
+    global $PHP_SELF;
 
-    if ($delete_id) {
+    if ( sqgetGlobalVar('delete_id', $delete_id, SQ_GET) ) {
         delete_move_next_delete();
         fix_sort_array();
-    } elseif ($move_id) {
+    } elseif ( sqgetGlobalVar('move_id', $move_id, SQ_POST) ) {
         delete_move_next_move();
         fix_sort_array();
     }
-
 }
 
 function delete_move_next_read_t() {
@@ -134,44 +151,38 @@ function delete_move_next_read_b() {
     }
 }
 
-
 function delete_move_next_read($currloc) {
     global $delete_move_next_formATtop, $delete_move_next_formATbottom,
            $color, $where, $what, $currentArrayIndex, $passed_id,
-           $urlMailbox, $sort, $startMessage, $delete_id, $move_id,
-           $imapConnection, $auto_expunge, $move_to_trash;
+           $mailbox, $sort, $startMessage, $delete_id, $move_id,
+           $imapConnection, $auto_expunge, $move_to_trash, $mbx_response,
+           $uid_support, $passed_ent_id;
 
-    if (!(($where && $what) || ($currentArrayIndex == -1))) {
-        $next = findNextMessage();
-        $prev = findPreviousMessage();
+    $urlMailbox = urlencode($mailbox);
+
+    if (!isset($passed_ent_id)) $passed_ent_id = 0;
+
+    if (!(($where && $what) || ($currentArrayIndex == -1)) && !$passed_ent_id) {
+        $next = findNextMessage($passed_id);
+        $prev = findPreviousMessage($mbx_response['EXISTS'], $passed_id);
         $prev_if_del = $prev;
         $next_if_del = $next;
-        if ($auto_expunge || $move_to_trash) {
+        if (!$uid_support && ($auto_expunge || $move_to_trash)) {
             if ($prev_if_del > $passed_id) {
                 $prev_if_del--;
             }
             if ($next_if_del > $passed_id) {
                 $next_if_del--;
             }
-        }    
-        
-	/* Base is illegal within documents 
+        }
+
+        /* Base is illegal within documents 
         * $location = get_location();
         * echo "<base href=\"$location/\">" . */
         echo '<table cellspacing=0 width="100%" border=0 cellpadding=2>'.
              '<tr>'.
                  "<td bgcolor=\"$color[9]\" width=\"100%\" align=center><small>";
-    
-        if ($prev > 0) {
-            echo "<a href=\"read_body.php?passed_id=$prev&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0\">" . _("Previous") . "</A>&nbsp;|&nbsp;\n";
-        } else {
-            echo _("Previous") . "&nbsp;|&nbsp;";
-        }
-        if ($next > 0) {
-            echo "<a href=\"read_body.php?passed_id=$next&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0\">" . _("Next") . "</A>&nbsp;|&nbsp;\n";
-        } else {
-            echo _("Next") . "&nbsp;|&nbsp;";
-        }
+
         if ($prev > 0){
             echo "<a href=\"read_body.php?passed_id=$prev_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;delete_id=$passed_id\">" . _("Delete & Prev") . "</a>" . "&nbsp;|&nbsp;\n";
         }
@@ -184,18 +195,18 @@ function delete_move_next_read($currloc) {
             echo _("Delete & Next");
         }
         echo '</small></td></tr>';
-        
+
         if ($next_if_del < 0) {
             $next_if_del = $prev_if_del;
         }
-        if (($delete_move_next_formATtop == 'on') && ($currloc == 'top')){
+        if (($delete_move_next_formATtop == 'on') && ($currloc == 'top')) {
             if ($next_if_del > 0) {
                 delete_move_next_moveNextForm($next_if_del);
             } else {
                 delete_move_next_moveRightMainForm();
             }
         }
-        if (($delete_move_next_formATbottom != 'off') && ($currloc == 'bottom')){
+        if (($delete_move_next_formATbottom != 'off') && ($currloc == 'bottom')) {
             if ($next_if_del > 0) {
                 delete_move_next_moveNextForm($next_if_del);
             } else {
@@ -207,34 +218,24 @@ function delete_move_next_read($currloc) {
 }
 
 function get_move_target_list() {
-    global $imapConnection;
-    
-    $boxes = sqimap_mailbox_list($imapConnection);
-    for ($i = 0; $i < count($boxes); $i++) {  
-        if (!in_array('noselect', $boxes[$i]['flags'])) {
-            $box = $boxes[$i]['unformatted'];
-            $box2 = str_replace(' ', '&nbsp;', $boxes[$i]['unformatted-disp']);
-            if ( $box2 == 'INBOX' ) {
-                $box2 = _("INBOX");
-            }
-            echo "<option value=\"$box\">$box2</option>\n";
-        }
+    global $imapConnection, $lastTargetMailbox;
+    if (isset($lastTargetMailbox) && !empty($lastTargetMailbox)) {
+        echo sqimap_mailbox_option_list($imapConnection, array(strtolower($lastTargetMailbox)));
+    }
+    else {
+        echo sqimap_mailbox_option_list($imapConnection);
     }
 }
 
 function delete_move_next_moveNextForm($next) {
 
     global $color, $where, $what, $currentArrayIndex, $passed_id,
-           $urlMailbox, $sort, $startMessage, $delete_id, $move_id,
+           $mailbox, $sort, $startMessage, $delete_id, $move_id,
            $imapConnection;
 
     echo '<tr>'.
          "<td bgcolor=\"$color[9]\" width=\"100%\" align=\"center\">".
-           '<form action="read_body.php" method="post"><small>'.
-            "<input type=\"hidden\" name=\"passed_id\" value=\"$next\">".
-            "<input type=\"hidden\" name=\"mailbox\" value=\"$urlMailbox\">".
-            "<input type=\"hidden\" name=\"sort\" value=\"$sort\">".
-            "<input type=\"hidden\" name=\"startMessage\" value=\"$startMessage\">".
+           "<form action=\"read_body.php?mailbox=$mailbox&sort=$sort&startMessage=$startMessage&passed_id=$next\" method=\"post\"><small>".
             "<input type=\"hidden\" name=\"show_more\" value=\"0\">".
             "<input type=\"hidden\" name=\"move_id\" value=\"$passed_id\">".
             _("Move to:") .
@@ -246,20 +247,17 @@ function delete_move_next_moveNextForm($next) {
            '</form>'.
          '</td>'.
          '</tr>';
-
 }
+
 function delete_move_next_moveRightMainForm() {
 
     global $color, $where, $what, $currentArrayIndex, $passed_id,
-           $urlMailbox, $sort, $startMessage, $delete_id, $move_id,
+           $mailbox, $sort, $startMessage, $delete_id, $move_id,
            $imapConnection;
 
-    echo '<tr>' .      
+    echo '<tr>' .
             "<td bgcolor=\"$color[9]\" width=\"100%\" align=\"center\">".
-            '<form action="right_main.php" method="post"><small>' .
-            "<input type=\"hidden\" name=\"mailbox\" value=\"$urlMailbox\">".
-            "<input type=\"hidden\" name=\"sort\" value=\"$sort\">".
-            "<input type=\"hidden\" name=\"startMessage\" value=\"$startMessage\">".
+            "<form action=\"right_main.php?mailbox=$mailbox&sort=$sort&startMessage=$startMessage\" method=\"post\"><small>" .
             "<input type=\"hidden\" name=\"move_id\" value=\"$passed_id\">".
             _("Move to:") .
             ' <select name="targetMailbox">';
@@ -270,59 +268,68 @@ function delete_move_next_moveRightMainForm() {
          '</form>' .
          '</td>'.
          '</tr>';
-
 }
 
-
 function delete_move_next_delete() {
-    global $imapConnection, $delete_id, $mailbox, $auto_expunge;
-    
+    global $imapConnection, $auto_expunge;
+
+    sqgetGlobalVar('delete_id', $delete_id, SQ_GET);
+    sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
+
     sqimap_messages_delete($imapConnection, $delete_id, $delete_id, $mailbox);
-    if ($auto_expunge){
+    if ($auto_expunge) {
         delete_move_expunge_from_all($delete_id);
-        // sqimap_mailbox_expunge($imapConnection, $mailbox, true);    
+        // sqimap_mailbox_expunge($imapConnection, $mailbox, true);
     }
 }
 
 function delete_move_next_move() {
-    global $imapConnection, $move_id, $targetMailbox, $auto_expunge, $mailbox;
-    
+    global $imapConnection, $mailbox, $auto_expunge, $lastTargetMailbox;
+
+    sqgetGlobalVar('move_id', $move_id, SQ_POST);
+    sqgetGlobalVar('mailbox', $mailbox, SQ_FORM);
+    sqgetGlobalVar('targetMailbox', $targetMailbox, SQ_POST);
+
     // Move message
     sqimap_messages_copy($imapConnection, $move_id, $move_id, $targetMailbox);
-    sqimap_messages_flag($imapConnection, $move_id, $move_id, 'Deleted');
+    sqimap_messages_flag($imapConnection, $move_id, $move_id, 'Deleted', true);
     if ($auto_expunge) {
         delete_move_expunge_from_all($move_id);
         // sqimap_mailbox_expunge($imapConnection, $mailbox, true);
     }
+
+    if ($targetMailbox != $lastTargetMailbox) {
+        $lastTargetMailbox = $targetMailbox;
+        sqsession_register($lastTargetMailbox, 'lastTargetMailbox');
+    }
 }
 
 function delete_move_next_display_inside() {
     global $username,$data_dir,
         $delete_move_next_t, $delete_move_next_formATtop,
         $delete_move_next_b, $delete_move_next_formATbottom;
-    
-    echo "<tr><td align=right valign=top>\n".
-         _("Delete/Move/Next Buttons:") . "</td>\n".
+
+    echo "<tr>" . html_tag('td',_("Delete/Move/Next Buttons:"),'right','','valign=top') . "\n".
          "<td><input type=checkbox name=delete_move_next_ti";
-         
+
     if ($delete_move_next_t == 'on') {
         echo " checked";
     }
     echo '> ' . _("Display at top").
          " <input type=checkbox name=delete_move_next_formATtopi";
-         
+
     if ($delete_move_next_formATtop == 'on') {
         echo ' checked';
     }
-    echo '> ' . _("with move option") . '<br>';    
-    
+    echo '> ' . _("with move option") . '<br>';
+
     echo '<input type=checkbox name=delete_move_next_bi';
     if($delete_move_next_b != 'off') {
         echo ' checked';
     }
     echo '> ' . _("Display at bottom") .
          '<input type=checkbox name=delete_move_next_formATbottomi';
-         
+
     if ($delete_move_next_formATbottom != 'off') {
         echo ' checked';
     }
@@ -332,43 +339,39 @@ function delete_move_next_display_inside() {
 
 function delete_move_next_display_save() {
 
-    global $username,$data_dir,
-           $delete_move_next_ti, $delete_move_next_formATtopi,
-           $delete_move_next_bi, $delete_move_next_formATbottomi;
-    
-    if (isset($delete_move_next_ti)) {
+    global $username,$data_dir;
+
+    if ( sqgetGlobalVar('delete_move_next_ti', $delete_move_next_ti, SQ_POST) ) {
         setPref($data_dir, $username, 'delete_move_next_t', 'on');
     } else {
         setPref($data_dir, $username, 'delete_move_next_t', "off");
     }
-    
-    if (isset($delete_move_next_formATtopi)) {
+
+    if ( sqgetGlobalVar('delete_move_next_formATtopi', $delete_move_next_formATtopi, SQ_POST) ) {
         setPref($data_dir, $username, 'delete_move_next_formATtop', 'on');
     } else {
         setPref($data_dir, $username, 'delete_move_next_formATtop', "off");
     }
-    
-    
-    if (isset($delete_move_next_bi)) {
+
+
+    if ( sqgetGlobalVar('delete_move_next_bi', $delete_move_next_bi, SQ_POST) ) {
         setPref($data_dir, $username, 'delete_move_next_b', 'on');
     } else {
         setPref($data_dir, $username, 'delete_move_next_b', "off");
     }
-    
-    if (isset($delete_move_next_formATbottomi)) {
+
+    if ( sqgetGlobalVar('delete_move_next_formATbottomi', $delete_move_next_formATbottomi, SQ_POST) ) {
         setPref($data_dir, $username, 'delete_move_next_formATbottom', 'on');
     } else {
         setPref($data_dir, $username, 'delete_move_next_formATbottom', "off");
     }
-
 }
 
-
 function delete_move_next_loading_prefs() {
     global $username,$data_dir,
            $delete_move_next_t, $delete_move_next_formATtop,
            $delete_move_next_b, $delete_move_next_formATbottom;
-    
+
     $delete_move_next_t = getPref($data_dir, $username, 'delete_move_next_t');
     $delete_move_next_b = getPref($data_dir, $username, 'delete_move_next_b');
     $delete_move_next_formATtop = getPref($data_dir, $username, 'delete_move_next_formATtop');
