@@ -1,13 +1,13 @@
 /**
  * init.js
- * -------
+ *
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Grabs the text from the SquirrelMail field and submits it to
  * the squirrelspell.
  *
- * $Id: init.js,v 1.2 2002/01/31 03:45:53 graf25 Exp $
- *
- * @author Konstantin Riabitsev <icon@duke.edu> ($Author: graf25 $)
- * @version $Date: 2002/01/31 03:45:53 $
+ * $Id: init.js,v 1.2.4.2 2004/12/29 23:19:37 jervfors Exp $
  */
 
 /**
@@ -19,7 +19,7 @@
  * @return      void 
  */
 function sqspell_init(flag){
-  textToSpell = opener.document.forms[0].subject.value + "\n" + opener.document.forms[0].body.value;
+  textToSpell = opener.document.compose.subject.value + "\n" + opener.document.compose.body.value;
   document.forms[0].sqspell_text.value = textToSpell;
   if (flag) document.forms[0].submit();
 }
