@@ -2,18 +2,20 @@
 /**
  * sqspell_config.php -- SquirrelSpell Configuration file.
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  *
  *
- * $Id: sqspell_config.php,v 1.9 2002/01/31 04:54:13 graf25 Exp $
+ * $Id: sqspell_config.php,v 1.14.2.2 2004/12/27 15:03:58 kink Exp $
  */
 
-require_once('../functions/prefs.php');
+require_once(SM_PATH . 'functions/prefs.php');
 
 /* Just for poor wretched souls with E_ALL. :) */
-global $username, $data_dir;
+global $data_dir;
+
+sqgetGlobalVar('username', $username, SQ_SESSION);
 
 /**
  * Example:
@@ -28,7 +30,5 @@ $SQSPELL_WORDS_FILE =
    getHashedFile($username, $data_dir, "$username.words");
 
 $SQSPELL_EREG = 'ereg';
-$SQSPELL_SOUP_NAZI = 'Mozilla/3, Mozilla/2, Opera 4, Opera/4, '
-   . 'Macintosh, OmniWeb';
 
 ?>
