@@ -4,13 +4,15 @@
  * ----------------------
  * All SquirrelSpell-wide functions are in this file.
  *
- * Copyright (c) 1999-2002 The SquirrelMail development team
+ * Copyright (c) 1999-2005 The SquirrelMail development team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: sqspell_functions.php,v 1.8 2002/03/06 02:09:21 graf25 Exp $
+ * $Id: sqspell_functions.php,v 1.14.2.7 2004/12/27 15:03:58 kink Exp $
  *
- * @author Konstantin Riabitsev <icon@duke.edu> ($Author: graf25 $)
- * @version $Date: 2002/03/06 02:09:21 $
+ * @author Konstantin Riabitsev <icon@duke.edu> ($Author: kink $)
+ * @version $Date: 2004/12/27 15:03:58 $
+ * @package plugins
+ * @subpackage squirrelspell
  */
 
 /**
@@ -26,44 +28,55 @@
  * @return            void
  */
 function sqspell_makePage($title, $scriptsrc, $body){
-  global $color, $SQSPELL_VERSION, $MOD;
+  global $color, $SQSPELL_VERSION;
+
+  if (! sqgetGlobalVar('MOD', $MOD, SQ_GET) ) {
+      $MOD = 'options_main';
+  }
+
   displayPageHeader($color, 'None');  
-  echo "&nbsp;<br>\n";
+  echo "&nbsp;<br />\n";
   /**
    * Check if we need to link in a script.
    */
   if($scriptsrc) { 
     echo "<script type=\"text/javascript\" src=\"js/$scriptsrc\"></script>\n";
   }
-  echo '<table width="95%" align="center" border="0" cellpadding="2" '
-    . 'cellspacing="0">'
-    . '<tr>'
-    . "<td bgcolor=\"$color[9]\" align=center>"
-    . "<strong>$title</strong>"
-    . '</td>'
-    . '</tr>'
-    . '<tr><td><hr></td></tr>'
-    . "<tr><td>$body</td></tr>";
+  echo html_tag( 'table', '', 'center', '', 'width="95%" border="0" cellpadding="2" cellspacing="0"' ) . "\n"
+    . html_tag( 'tr', "\n" .
+          html_tag( 'td', '<strong>' . $title .'</strong>', 'center', $color[9] )
+      ) . "\n"
+    . html_tag( 'tr', "\n" .
+          html_tag( 'td', '<hr>', 'left' )
+      ) . "\n"
+    . html_tag( 'tr', "\n" .
+          html_tag( 'td', $body, 'left' )
+      ) . "\n";
   /**
    * Generate a nice "Return to Options" link, unless this is the
    * starting page.
    */
   if ($MOD != "options_main"){ 
-    echo '<tr><td><hr></td></tr>'
-      . '<tr><td align="center"><a href="sqspell_options.php">'
-      . _("Back to &quot;SpellChecker Options&quot; page") 
-      . '</a></td></tr>';
+    echo html_tag( 'tr', "\n" .
+                html_tag( 'td', '<hr>', 'left' )
+            ) . "\n"
+      . html_tag( 'tr', "\n" .
+            html_tag( 'td', '<a href="sqspell_options.php">'
+                . _("Back to &quot;SpellChecker Options&quot; page")
+                . '</a>',
+            'center' )
+        ) . "\n";
   }
   /**
    * Close the table and display the version.
    */
-  echo '<tr><td><hr></td></tr>'
-    . '<tr>'
-    . "<td bgcolor=\"$color[9]\" align=center>"
-    . "SquirrelSpell $SQSPELL_VERSION"
-    . '</td>'
-    . '</tr>'
-    . '</table>';
+  echo html_tag( 'tr', "\n" .
+              html_tag( 'td', '<hr>', 'left' )
+          ) . "\n"
+    . html_tag( 'tr',
+          html_tag( 'td', 'SquirrelSpell ' . $SQSPELL_VERSION, 'center', $color[9] )
+      ) . "\n</table>\n";
+  echo '</body></html>';
 }
 
 /**
@@ -82,24 +95,12 @@ function sqspell_makePage($title, $scriptsrc, $body){
  * @return            void
  */
 function sqspell_makeWindow($onload, $title, $scriptsrc, $body){
-  global $color, $SQSPELL_VERSION, $theme_css;
-  echo "<html>\n"
-    . "<head>\n"
-    . "<title>$title</title>\n";
-  /**
-   * Check if we have a defined css theme to use.
-   */
-  if ($theme_css != "") {
-    echo "<LINK REL=\"stylesheet\" TYPE=\"text/css\" HREF=\"$theme_css\">\n";
-  }
-  /**
-   * Link in the .js file if needed
-   */         
-  if ($scriptsrc){
-    echo "<script type=\"text/javascript\" src=\"js/$scriptsrc\"></script>\n";
-  }
-  echo "</head>\n"
-    . "<body text=\"$color[8]\" bgcolor=\"$color[4]\" link=\"$color[7]\" "
+  global $color, $SQSPELL_VERSION;
+
+  displayHtmlHeader($title,
+        ($scriptsrc ? "\n<script type=\"text/javascript\" src=\"js/$scriptsrc\"></script>\n" : ''));
+
+  echo "<body text=\"$color[8]\" bgcolor=\"$color[4]\" link=\"$color[7]\" "
     . "vlink=\"$color[7]\" alink=\"$color[7]\"";
   /**
    * Provide an onload="jsfunction()" if asked to.
@@ -111,23 +112,23 @@ function sqspell_makeWindow($onload, $title, $scriptsrc, $body){
    * Draw the rest of the page.
    */
   echo '>'
-    . '<table width="100%" border="0" cellpadding="2">'
-    . '<tr>'
-    . "<td bgcolor=\"$color[9]\" align=center>"
-    . "<strong>$title</strong>"
-    . '</td>'
-    . '</tr>'
-    . '<tr><td><hr></td></tr>'
-    . '<tr>'
-    . "<td>$body</td>"
-    . '</tr>'
-    . '<tr><td><hr></td></tr>'
-    . '<tr>'
-    . "<td bgcolor=\"$color[9]\" align=center>"
-    . "SquirrelSpell $SQSPELL_VERSION"
-    . '</td>'
-    . '</tr>'
-    . '</table>'
+    . html_tag( 'table', "\n" .
+          html_tag( 'tr', "\n" .
+              html_tag( 'td', '<strong>' . $title . '</strong>', 'center', $color[9] )
+          ) . "\n" .
+          html_tag( 'tr', "\n" .
+              html_tag( 'td', '<hr>', 'left' )
+          ) . "\n" .
+          html_tag( 'tr', "\n" .
+              html_tag( 'td', $body, 'left' )
+          ) . "\n" .
+          html_tag( 'tr', "\n" .
+              html_tag( 'td', '<hr>', 'left' )
+          ) . "\n" .
+          html_tag( 'tr', "\n" .
+              html_tag( 'td', 'SquirrelSpell ' . $SQSPELL_VERSION, 'center', $color[9] )
+          ) ,
+      '', '', 'width="100%" border="0" cellpadding="2"' )
     . "</body>\n</html>\n";
 }
 
@@ -150,7 +151,7 @@ function sqspell_crypto($mode, $ckey, $input){
    * Double-check if we have the mcrypt_generic function. Bail out if
    * not so.
    */
-  if (!function_exists(mcrypt_generic)) {
+  if (!function_exists('mcrypt_generic')) {
     return 'PANIC';
   }
   /**
@@ -182,7 +183,14 @@ function sqspell_crypto($mode, $ckey, $input){
   /**
    * Finish up the mcrypt routines and return the processed content.
    */
-  mcrypt_generic_end ($td);
+  if (function_exists('mcrypt_generic_deinit')) {
+      // php 4.1.1+ syntax
+      mcrypt_generic_deinit ($td);
+      mcrypt_module_close ($td);
+  } else {
+      // older deprecated function
+      mcrypt_generic_end ($td);
+  }
   return $crypto;
 }
 
@@ -326,9 +334,13 @@ function sqspell_getWords(){
      * the user's old mailbox password. I admin, this is rather dirty,
      * but efficient. ;)
      */
-    global $key, $onetimepad, $old_key;
-    if ($old_key) {
-      $clear_key=$old_key;
+    sqgetGlobalVar('key', $key, SQ_COOKIE);
+    sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
+
+    sqgetGlobalVar('old_key', $old_key, SQ_POST);
+
+    if ($old_key != '') {
+        $clear_key=$old_key;
     } else {
       /**
        * Get user's password (the key).
@@ -352,21 +364,25 @@ function sqspell_getWords(){
        * The _("SquirrelSpell...) line has to be on one line, otherwise
        * gettext will bork. ;(
        */
-      $msg='<p>'
-	 . '<strong>' . _("ATTENTION:") . '</strong><br>'
-	 .  _("SquirrelSpell was unable to decrypt your personal dictionary. This is most likely due to the fact that you have changed your mailbox password. In order to proceed, you will have to supply your old password so that SquirrelSpell can decrypt your personal dictionary. It will be re-encrypted with your new password after this.<br>If you haven't encrypted your dictionary, then it got mangled and is no longer valid. You will have to delete it and start anew. This is also true if you don't remember your old password -- without it, the encrypted data is no longer accessible.")
-	 . '</p>'
-	 . '<blockquote>'
-	 . '<form method="post" onsubmit="return AYS()">'
-	 . '<input type="hidden" name="MOD" value="crypto_badkey">'
-	 . '<p><input type="checkbox" name="delete_words" value="ON">'
-	 . _("Delete my dictionary and start a new one") . '<br>'
-	 . _("Decrypt my dictionary with my old password:")
-	 . '<input name="old_key" size=\"10\"></p>'
-	 . '</blockquote>'
-	 . '<p align="center"><input type="submit" value="' 
-	 . _("Proceed") . ' &gt;&gt;"></p>'
-	 . '</form>';
+      $msg = html_tag( 'p', "\n" .
+                     '<strong>' . _("ATTENTION:") . '</strong><br />'
+                     .  _("SquirrelSpell was unable to decrypt your personal dictionary. This is most likely due to the fact that you have changed your mailbox password. In order to proceed, you will have to supply your old password so that SquirrelSpell can decrypt your personal dictionary. It will be re-encrypted with your new password after this. If you haven't encrypted your dictionary, then it got mangled and is no longer valid. You will have to delete it and start anew. This is also true if you don't remember your old password -- without it, the encrypted data is no longer accessible.") ,
+                 'left' ) .  "\n"
+	 . '<blockquote>' . "\n"
+	 . '<form method="post" onsubmit="return AYS()">' . "\n"
+	 . '<input type="hidden" name="MOD" value="crypto_badkey">' . "\n"
+	 . html_tag( 'p',  "\n" .
+	       '<input type="checkbox" name="delete_words" value="ON">'
+	       . _("Delete my dictionary and start a new one") . '<br />'
+	       . _("Decrypt my dictionary with my old password:")
+	       . '<input name="old_key" size=\"10\">' ,
+	   'left' ) . "\n"
+	 . '</blockquote>' . "\n"
+	 . html_tag( 'p', "\n" .
+	       '<input type="submit" value="' 
+	       . _("Proceed") . ' &gt;&gt;">' ,
+	   'center' ) . "\n"
+	 . '</form>' . "\n";
       /**
        * Add some string vars so they can be i18n'd.
        */
@@ -434,7 +450,9 @@ function sqspell_writeWords($words){
      * User wants to encrypt the file. So be it.
      * Get the user's password to use as a key.
      */
-    global $key, $onetimepad;
+    sqgetGlobalVar('key', $key, SQ_COOKIE);
+    sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
+
     $clear_key=OneTimePadDecrypt($key, $onetimepad);
     /**
      * Try encrypting it. If fails, scream bloody hell.
